# pybudgea
# Budgea Development Guides

Welcome to **Budgea**'s documentation.

This documentation is intended to get you up-and-running with our APIs and advise on the implementation of some regulatory aspects of your application, following the DSP2's guidelines.

## Getting Started
**IMPORTANT**
Depending on your status with regard of the DSP2 regulation, **agent** or **partner**, you may call our APIs or simply use our Webview and callbacks to get the financial data of your users.
As an **agent**, you are allowed to call directly our APIs and implement your own form to get the user's credentials.
As a **partner**, you cannot manipulate the credentials, and have to delegate this step to us through our webview.

The sections below will document how to use our APIs, make sure you have the **agent** status to do so.
For the **partner**, please refer to the section *Webview* and *Callbacks* of this documentation.

### Overview
Your API is a REST API which requires a communication through https to send and receive JSON documents.
During your tests, we recommend to make calls to the API with curl or any other HTTP client of your choice.
You can watch a video demonstration on this [URL](https://asciinema.org/a/FsaFyt3WAPyDm7sfaZPkwal3V).
For the examples we'll use the demo API with address `https://demo.biapi.pro`, you should change that name to your API's name.

### Hello World
Let's start by calling the service `/banks` which lists all available banks.
```
curl https://demo.biapi.pro/2.0/banks/
```
To log in to a bank webpage, you'll need to know for a given bank, the fields your user should fill in the form.
Let's call a  specific bank and ask for an additional resource *fields*.
```
curl https://demo.biapi.pro/2.0/banks/59?expand=fields
```
The response here concerns only 1 bank (since we specified an id) and the resource _Fields_ is added to the response thanks to the query parameter `expand`.

To get more interesting things done, you'll need to send authenticated requests.

### Authentication
The way to authenticate is by passing the `Authorization: Bearer <token>` header in your request.
At the setup a _manage token_ have been generated, you can use this token for now, when creating your user we'll see how to generate a user's token.
```
curl https://demo.biapi.pro/2.0/config \\
  -H 'Authorization: Bearer <token>'
```
This endpoint will list all the parameters you can change to adapt Budgea to your needs.

We've covered the very first calls. Before diving deeper, let's see some general information about the APIs.

## Abstract

### API URL
`https://demo.biapi.pro/2.0`

### Requests format
Data format: **application/x-www-form-urlencoded** or **application/json** (suggested)

Additional headers: Authorization: User's token (private)

### Responses format
Data format: **application/json** ([http://www.json.org](http://www.json.org/))
Charset: **UTF-8**

### Resources
Each call on an endpoint will return resources. The main resources are:
| Resource            | Description                                                                                                           |
| ---------------------|:------------------------------------------------------------------------------------------------------------------   |
|Users                 |Represent a user                                                                                                      |
|Connection            |A set of data used to authenticate on a website (usually a login and password). There is 1 connection for each website|
|Account               |A bank account contained in a connection                                                                              |
|Transaction           |An entry in a bank account                                                                                            |
|Investment            |An asset in a bank account                                                                                            |

The chain of resources is as follow: **Users ∈ Connections ∈ Accounts ∈ Transactions or Investments**

### RESTful API

This API is RESTful, which means it is stateless and each resource is accessed with an unique URI.

Several HTTP methods are available:

| Method                  | Description                    |
| ------------------------|:-------------------------------|
| GET /resources          | List resources                 |
| GET /resources/{ID}     | Get a resource from its ID     |
| POST /resources         | Create a new resource          |
| POST /resources/{ID}    | Update a resource              |
| PUT /resources  /{ID}   | Update a resource              |
| DELETE /resources       | Remove every resources         |
| DELETE /resources/{ID}  | Delete a resource              |


Each resource can contain sub-resources, for example:
`/users/me/connections/2/accounts/23/transactions/48`

### HTTP response codes

| Code        | Message               | Description                                                                                   |
| ----------- |:---------------------:|-----------------------------------------------------------------------------------------------|
| 200         | OK                    |Default response when a GET or POST request has succeed                                        |
| 202         | Accepted              |For a new connection this code means it is necessary to provide complementary information (2FA)|
| 204         | No content            |Default response when a POST request succeed without content                                   |
| 400         | Bad request           |Supplied parameters are incorrect                                                              |
| 403         | Forbidden             |Invalid token                                                                                  |
| 500         | Internal Servor Error |Server error                                                                                   |
| 503         | Service Unavailable   |Service is temporarily unavailable                                                             |

### Errors management
In case an error occurs (code 4xx or 5xx), the response can contain a JSON object describing this error:
```json
{
   \"code\": \"authFailure\",
   \"message\": \"Wrong password\"  // Optional
}
```
If an error is displayed on the website, Its content is returned in error_message field.
The list of all possible errors is listed further down this page.

### Authentication
A user is authenticated by an access_token which is sent by the API during a call on one of the authentication services, and can be supplied with this header:
`Authorization: Bearer YYYYYYYYYYYYYYYYYYYYYYYYYYY`

 There are two user levels:

    - Normal user, which can only access to his own accounts
    - Administrator, with extended rights

### Default filters
During a call to an URI which lists resources, some filters can be passed as query parameters:

| Parameter   | Type      | Description                                               |
| ----------- |:---------:|-----------------------------------------------------------|
| offset      | Integer   |Offset of the first returned resource                      |
| limit       | Integer   |Limit number of results                                    |
| min_date    | Date      |Minimal date (if supported by service), format: YYYY-MM-DD |
| max_date    | Date      |Maximal date (if supported by service), format: YYYY-MM-DD |

### Extend requests
During a GET on a set of resources or on a unique resource, it is possible to add a parameter expand to the request to extend relations with other resources:

`GET /2.0/users/me/accounts/123?expand=transactions[category],connection`

```json
{
   \"id\" : 123
   \"name\" : \"Compte chèque\"
   \"balance\" : 1561.15
   \"transactions\" : [
      {
         \"id\" : 9849,
         \"simplified_wording\" : \"HALL'S BEER\",
         \"value\" : -513.20,
         ...
         \"category\" : {
            \"id\" : 561,
            \"name\" : \"Sorties / Bar\",
            ...
         }
       },
       ...
   ],
   \"id_user\" : 1,
   \"connection\" : {
      \"id\" : 1518,
      \"id_bank\" : 41,
      \"id_user\" : 1,
      \"error\" : null,
      ...
   }
}
```

### Request example
```http
GET /2.0/banks?offset=0&limit=10&expand=fields
Host: demo.biapi.pro
Accept: application/json
Authorization: Bearer <token>
```
```http
HTTP/1.1 200 OK
Content-Type: application/json
Content-Length: 3026
Server: Apache
Date: Fri, 14 Mar 2014 08:24:02 GMT

{
   \"banks\" : [
      {
         \"id_weboob\" : \"bnporc\",
         \"name\" : \"BNP Paribas\",
         \"id\" : 3,
         \"hidden\" : false,
         \"fields\" : [
            {
               \"id\" : 1,
               \"id_bank\" : 3,
               \"regex\" : \"^[0-9]{5,10}$\",
               \"name\" : \"login\",
               \"type\" : \"text\",
               \"label\" : \"Numéro client\"
            },
            {
               \"id\" : 2,
               \"id_bank\" : 3,
               \"regex\" : \"^[0-9]{6}$\",
               \"name\" : \"password\",
               \"type\" : \"password\",
               \"label\" : \"Code secret\"
            }
         ]
      },
      ...
   ]
   \"total\" : 41
}
```

### Constants
#### List of bank account types
| Type          |Description                        |
| -----------   |-----------------------------------|
| checking      |Checking account                   |
| savings       |Savings account                    |
| deposit       |Deposit accounts                   |
| loan          |Loan                               |
| market        | Market accounts                   |
| joint         |Joint account                      |
| card          |Card                               |
| lifeinsurance |Life insurance accounts            |
| pee           |Plan Épargne Entreprise            |
| perco         |Plan Épargne Retraite              |
| article83     |Article 83                         |
| rsp           |Réserve spéciale de participation  |
| pea           |Plan d'épargne en actions          |
| capitalisation|Contrat de capitalisation          |
| perp          |Plan d'épargne retraite populaire  |
| madelin       |Contrat retraite Madelin           |
| unknown       |Inconnu                            |

#### List of transaction types

| Type         |Description                        |
| -----------  |-----------------------------------|
|transfer      |Transfers                          |
|order         |Orders                             |
|check         |Checks                             |
|deposit       |Cash deposit                       |
|payback       |Payback                            |
|withdrawal    |Withdrawal                         |
|loan_payment  |Loan payment                       |
|bank          |Bank fees                          |
|card          |Card operation                     |
|deferred_card |Deferred card operation            |
|card_summary  |Mensual debit of a deferred card   |

#### List of synchronization errors
##### Error on Connection object
The error field may take one of the below values in case of error when accessing the user space.

| Error                      |Description                                                                                       |
| -----------------------    |--------------------------------------------------------------------------------------------------|
|wrongpass                   |The authentication on website has failed                                                          |
|additionalInformationNeeded |Additional information is needed such as an OTP                                                  |
|websiteUnavailable          |The website is unavailable, for instance we get a HTTP 503 response when requesting the website   |
|actionNeeded                |An action is needed on the website by the user, scraping is blocked                               |
|SCARequired                |An SCA process must be done by updating the connection                               |
|decoupled                  |Requires a user validation (ex: digital key)|
|passwordExpired                   |The password has expired and needs to be changed on the website.                                                         |
|webauthRequired                |A complete authentication process is required by update the connection via redirect                            |
|bug                         |A bug has occurred during the synchronization. An alert has been sent to Budget Insight           |

#### Error on Account object
Errors can be filled at the account level in case we access the user's dashboard but some account related data cannot be retrieved.
For instance, we may not access the transactions or investments for a specific account.
Getting an error during an account synchronization does not impact the scraping of other acccounts.

| Error                      |Description                                                                                       |
| -----------------------    |--------------------------------------------------------------------------------------------------|
|websiteUnavailable          |The website or a page is unavailable                                                              |
|actionNeeded                |An action is needed on the website by the user, scraping is blocked                               |
|bug                         |A bug has occurred during the synchronization. An alert has been sent to Budget Insight           |

Now you know the basics of Budgea API
- Basic call to retrieve resources
- Add query parameters to aplly filters
- Expand resources
- Authenticated calls

We're good for the basics! Now let's see how to integrate Budgea in your app and create your first user.

## Integrate Budgea *(protocol or Webview)*
### The workflow
Users of your application exist in the Budgea API.
Every User is identified by an access_token which is the shared secret between your application and our API.

The workflow is as below:
1. The user is on your application and wants to share his bank accounts or invoices.
2. A call is made **client side** (browser's javascript or desktop application) to create a temporarily token which will be used to make API calls.
3. A form is built, allowing the user to select the connector to use (bank or provider, depending on context). Every connector requires different kind of credentials.
4. A call on the API is made with the temporarily token to add a **Connection** with the credentials supplied by user.
5. In case of success, the user chooses what bank accounts (**Account**) or subscriptions (**Subscription**) he wants to share with your application.
6. When he validates the share, the temporarily token is transmitted to your server. This one will call the Budgea API with this token to get a permanent token.

**Note**
In case your application works without a server (for example a desktop application), the permanent token can be obtained on the 1st step, by supplying a client_secret to /auth/init and the step 6 is omitted. To get more information, read the protocol.

There are 3 steps to integrate Budgea in your application:
1. Provide a way for your users to share their credentials with you
2. Get the data scraped from Budgea
3. Be sure to follow the good practices before going into production

### Get credentials from users
You have 2 options here:
- Integrate the Budget Insight's Webview, a turnkey solution to get user's credentials
- Create your own form following the protocol (must have the *agent* status)

### Budgea webview

The Budgea webview complements REST API endpoints with web-based services to handle sensitive or complex operations:
- add a connection (to a bank or a provider), or edit/repare access to a connection;
- manage connections (add/remove/edit);
- edit and validate bank transfers (alpha preview).

Usage of the webview is mandatory if you don't hold an Agent status, since you are not allowed to use API endpoints carrying user credentials, and optional otherwise.

#### Implementation guidelines

##### Base URL

The base URL of all services must be customized:  
`https://{{domain}}.biapi.pro/2.0/auth/webview/`  
`https://{{domain}}.biapi.pro/2.0/auth/webview/{{lang}}/`  
- `{{domain}}`: substitute with you API domain;
- `{{lang}}`: optionally specify the language of the webview, `en` or `fr` (if not specified, an automatic redirection will be performed following the language of the browser).

##### Browser integration

Services available as part of the webview are designed as parameterized URLs intended to be opened in a web browser. A callback URI must be specified by callers to be notified at the end of the operation flow, similar to OAuth 2 specification.

You are encouraged to integrate web-based steps in your product following UX best practices:
- in a web environment, perform a full-page redirect to the URL (using either [HTTP redirect](https://developer.mozilla.org/fr/docs/Web/HTTP/Status/302) or [scripting](https://developer.mozilla.org/fr/docs/Web/API/Location)), and avoid new tabs or popups;
- in a native Android app, prefer opening the default browser or relying on [Chrome Custom Tabs](https://developer.chrome.com/multidevice/android/customtabs) to integrating a WebView;
- in a native iOS app, prefer using a [SFSafariViewController](https://developer.apple.com/documentation/safariservices/sfsafariviewcontroller) to integrating a WKWebView.

##### Callback handling

Most flows redirect to a callback URI at the end of the process. Query parameters are added to the URI to identify successful or failed operations.

Successful parameters are specific to each flow. In case of an error, the following parameters are added:

| Parameter | Description |
| - | - |
| `error` | An lowercase string error code identifying the kind of error that occurred. When the parameter is not present, the response is successful. |
| `error_description` | A longer string description of the error (not intended for user display). |

Common error codes include:

| Code | Description |
| - | - |
| `access_denied` | The user explicitly cancelled the flow. |
| `server_error` | Oops, a technical failure occurred during the process. |

**Forward compatibility requirement**: Additional error codes may be added in the future to describe specific cases. When implementing error codes handling, always fallback to a generic case for unknown codes.

##### Browser compatibility

The webview is designed and tested to work with browsers supported by the Angular framework:  
https://angular.io/guide/browser-support

##### Privacy / GDPR status

The webview itself does not use any kind of long-term data persistence mechanism such as cookies or local storage, but some authentication or authorization steps may delegate to third-party web services that may implement them.

#### Configuration

You can configure the appearance and behaviour of the webview by configuring the associated *Client Application* in the console:

| Key | Format | Description |
| - | - | - |
| `primary_color` | String | Optional. An accent color (hexadecimal string without '#' prefix) to personalize the UI elements of the webview. If absent, the default color is grey. |
| `redirect_uri` | String | Optional. A recommended security whitelist configuration. The `redirect_uri` parameter sent to any endpoint of the webview is checked against the configuration, if any. |
| `config.disable_connector_hints` | Boolean | Optional. This flags hides the list of most-used entries in the connector selection step. The default is `false`, i.e. the list is shown. |
| `config.use_app_layout` | Boolean | Optional. Use this flag to enable presenting your log as an app icon. The default value is ` false`, i.e. the logo is shown in the top bar of the UI. |
| `config.disable_accounts_pre_check` | Boolean | Optional. An optional boolean flag to prevent bank accounts to be automatically pre-checked when the user enters the activation step. The default value is ` false`, i.e. the bank accounts are pre-checked. |

#### Endpoints reference

##### Add connection flow
```
https://{{domain}}.biapi.pro/2.0/auth/webview/{{lang}}/connect
```

This flow allows an end-user to add a new connection to the API. The flow handles the following steps:
- selecting a connector;
- authenticating & authorizing with the connector, by collecting credentials or delegating;
- managing consent to aggregate accounts/subscriptions;
- collecting required information for professional accounts.

###### Endpoint parameters

| Parameter | Description |
| - | - |
| `client_id` | Required. The ID of the requesting client application. You can manage client applications of your domain in the admin console. |
| `redirect_uri` | Required. An absolute callback URI. The webview will redirect to it at the end of the flow. |
| `code` | Optional. A user-scoped temporary code to use with the Budgea API.<br>If you don't provide a code, a new anonymous user will be created before the connection is added, and you will be returned an access token code scoped to it with the success callback. |
| `state` | Optional. An opaque string parameter that you can use to carry state across the flow. The parameter will be set \"as is\" on the callback URI. Make sure that the `state` you provide is properly URL-encoded. |
| `connector_ids` | Optional. A comma-separated list of connector IDs available to pick from.<br>If the parameter is omitted, all active connectors are available.<br>If you pass a single value, the user is not prompted to choose the connector.<br>This parameter is mutually exclusive with `connector_uuids`. |
| `connector_uuids` | Optional. A comma-separated list of connector UUIDs available to pick from.<br>If the parameter is omitted, all active connectors are available.<br>If you pass a single value, the user is not prompted to choose the connector.<br>This parameter is mutually exclusive with `connector_ids`. |
| `connector_capabilities` | Optional. A comma-separated list of capabilities to filter available connectors.<br>If the parameter is omitted, `bank` is inferred.<br>If multiple values are provided, only connectors that expose all the requested capabilities are available.<br>To request a bank connection, use `bank`.<br>To request a provider connection, use `document`. |
| `account_ibans` | Optional. A comma-separated list of IBANs to filter accounts available for activation in a bank connection context. Other accounts will not be selectable. |
| `account_types` | Optional. A comma-separated list of account types to filter accounts available for activation in a bank connection context. Other accounts will not be selectable. |
| `account_usages` | Optional. A comma-separated list of account usages to filter accounts available for activation in a bank connection context. Other accounts will not be selectable. |

###### Successful callback parameters

| Parameter | Description |
| - | - |
| `connection_id` | The id of the newly created connection. Please note that when redirecting to the callback URI, the accounts and/or subscriptions are available in the API, but bank transactions or documents may still be syncing in background. |
| `code` | Optional. If a `code` was *not* initially specified, an API code that you must exchange to obtain a permanent access token associated with the newly-created anonymous user holding the connection. The parameter is URL-encoded, make sure to handle it accordingly. |
| `state` | Optional. Identical to the `state` parameter that was initially specified. |

###### Additional error codes

| Code | Description |
| - | - |
| `tos_declined` | The end-user refused to validate the terms of service. |

##### Re-auth / edit connection credentials flow

```
https://{{domain}}.biapi.pro/2.0/auth/webview/{{lang}}/reconnect
```

This flow allows an end-user to re-authenticate against a bank or a provider in order to recover an existing connection, or to completely reset credentials associated with a connection.

###### Endpoint parameters

| Parameter | Description |
| - | - |
| `client_id` | Required. The ID of the requesting client application. You can manage client applications of your domain in the admin console. |
| `redirect_uri` | Required. An absolute callback URI. The webview will redirect to it at the end of the flow. |
| `code` | Required. A user-scoped temporary code to use with the Budgea API. |
| `connection_id` | Required. The id of the existing connection. |
| `state` | Optional. An opaque string parameter that you can use to carry state across the flow. The parameter will be set \"as is\" on the callback URI. Make sure that the `state` you provide is properly URL-encoded. |
| `reset_credentials` | Optional. In the default mode (`false`), the service will try to recover the connection and prompt the user only with outdated or transient information (new password, OTP...).<br>Set the parameter to `true` to force resetting all the credentials associated with the connection. This parameter may not apply to all connectors. |

###### Successful callback parameters

This flow adds no parameter to the callback URI in case of success, except from `state`.

##### Manage connections

```
https://{{domain}}.biapi.pro/2.0/auth/webview/{{lang}}/manage
```
This flow allows an end-user to manage the connections associated with his account in the API. The user can add new connections, remove existing ones, fix connection errors, reset credentials or activate/deactivate bank accounts.

Support of `redirect_uri` in this flow is optional, as it can be integrated or presented as a terminal step, without relying on a final redirection.

###### Endpoint parameters

| Parameter | Description |
| - | - |
| `client_id` | Required. The ID of the requesting client application. You can manage client applications of your domain in the admin console. |
| `code` | Required. A user-scoped temporary code to use with the Budgea API. |
| `redirect_uri` | Optional. An absolute callback URI. When provided, the webview will display a close button that redirects to it. |
| `state` | Optional. An opaque string parameter that you can use to carry state across the flow when providing a `redirect_uri`. The parameter will be set \"as is\" on the callback URI. Make sure that the `state` you provide is properly URL-encoded. |
| `connector_capabilities` | Optional. A comma-separated list of capabilities to filter available connectors when adding a new connection.<br>If the parameter is omitted, `bank` is inferred.<br>If multiple values are provided, only connectors that expose all the requested capabilities are available.<br>To request a bank connection, use `bank`.<br>To request a provider connection, use `document`. |
| `account_types` | Optional. A comma-separated list of account types to filter accounts available for activation on adding a new bank connection or updating existing connections. Other accounts will not be selectable. |
| `account_usages` | Optional. A comma-separated list of account usages to filter accounts available for activation in a bank connection context. Other accounts will not be selectable. |

###### Callback parameters

This flow adds no parameter to the callback URI, except from `state`.

##### Execute a bank transfer (preview)

**Disclaimer**: Transfer or payment services are available as a preview, protocols and parameters are subject to change in upcoming beta/final releases.

```
https://{{domain}}.biapi.pro/2.0/auth/webview/{{lang}}/transfer
```
This flow allows an end-user to execute a bank transfer. The flow handles the following steps:
- if the transfer is not already created, all steps to authenticate with a bank, select the recipient, the emitter account, the amount and label;
- executing the transfer, including managing SCAs for recipient registration and/or transfer validation.

###### Endpoint parameters

| Parameter | Description |
| - | - |
| `client_id` | Required. The ID of the requesting client application. You can manage client applications of your domain in the admin console. |
| `redirect_uri` | Required. An absolute callback URI. The webview will redirect to it at the end of the flow. |
| `code` | Required. A user-scoped temporary code to use with the Budgea API.<br>If you don't provide a code, a new anonymous user will be created before a connection is added and the transfer is executed, and you will be returned an access token code scoped to it with the success callback. |
| `state` | Optional. An opaque string parameter that you can use to carry state across the flow. The parameter will be set \"as is\" on the callback URI. Make sure that the `state` you provide is properly URL-encoded. |
| `transfer_id`| Optional. The ID of an prepared transfer to be validated in the webview. The user cannot edit anything on the transfer before validation. |

###### Successfull callback parameters

| Parameter | Description |
| - | - |
| `transfer_id` | The ID of the transfer that was created and executed. |
| `code` | Optional. If a `code` was *not* initially specified, an API code that you can exchange to obtain a permanent access token associated with the newly-created anonymous user holding the transfer. The parameter is URL-encoded, make sure to handle it accordingly. |
| `state` | Optional. Identical to the `state` parameter that was initially specified. |

###### Additional error codes

| Code | Description |
| - | - |
| `tos_declined` | The end-user refused to validate the terms of service. |

#### Migrating from v3

We provide a full backward compatibility layer with current implementations of the webview v3 to ease the transition. All endpoints remains accessible, with the same parameters and callback behaviour. Migration instructions are provided below.

*The v3 compatibility mode is expected to be removed on 31 December 2019.* You should migrate your implementation a soon as possible to new endpoints and parameters.

##### Add connection flow / Edit connection credentials  
```
/connect/select
```

This endpoint has been superseded by `/connect` (no suffix) for adding a new connection, and `/reconnect` for resetting or updating an existing connection.

| Endpoint parameter | Migration instructions |
| - | - |
| `client_id` | No change. |
| `redirect_uri`, `state` | No change. |
| `response_type` | This parameter is not used anymore. |
| `id_connector`, `connectors` | Superseded by `connector_ids` sent to the `/connect` endpoint. |
| `types` | Superseded by `connector_capabilities` sent to the `/connect` endpoint.<br>Use`connector_capabilities=bank` (bank connection) or `connector_capabilities=document` (provider connection). |
| `id_connection` | Superseded by `connection_id` sent to the `/reconnect` endpoint. |

Passing the code or access token as an URL fragment is no longer supported, use the `code` query parameter.

| Callback parameter | Migration instructions |
| - | - |
| `id_connection` | Superseded by `connection_id`.<br>In the `/reconnect` flow, this parameter is not returned anymore. |
| `code` | Still named `code`, but in the `/connect` flow the parameter is now **only** added if an anonymous user was created, i.e. the `code` parameter was **not** provided as a query parameter or fragment.<br>In the `/reconnect` flow, this parameter is not returned anymore. |
| `state` | No change. |

##### Manage connections

```
/accounts
```

This endpoint has been superseded by `/manage`, that now fully allows users to add/remove connections, reset their credentials or recover from error states.

| Endpoint parameter | Migration instructions |
| - | - |
| `client_id` | No change. |
| `redirect_uri`, `state` | No change, these parameters are now optional. |
| `response_type` | This parameter is not used anymore. |
| `types` | Superseded by `connector_capabilities`.<br>Use`connector_capabilities=bank` (bank connection) or `connector_capabilities=document` (provider connection). |

Passing the code or access token as an URL fragment is no longer supported, use the `code` query parameter.

| Callback parameter | Migration instructions |
| - | - |
| `code` | This parameter is not returned anymore. |
| `state` | No change. |

##### Behaviour change

In v3, the `/accounts` flow used to redirect to the `redirect_uri` after a connection addition. This is no longer the case in v4, where redirection is only performed when the user explicitly closes the flow. If you need to perform actions when a connection is added or removed, you should rely on webhooks.

#### Protocol
This section describes the protocol used to set bank and provider accounts of a user, in case you don't want to use the webview.

The idea is to call the following services client-side (with AJAX in case of a web application), to ensure the bank and providers credentials will not be sent to your servers.

1. /auth/init
```http
POST /auth/init
```
```json
{
   \"auth_token\" : \"fBqjMZbYddebUGlkR445JKPA6pCoRaGb\",
   \"type\" : \"temporary\",
   \"expires_in\" : 1800,
   \"id_user\": 1
}
```
This service creates a temporarily token, to use in the \"Authorization\" header in next calls to the API

The returned token has a life-time of 30 minutes, and should be transfered to the API then (cf Permanent Token), so that your server can get a permanent access_token.

It is possible to generate a permanent token immediately, by calling the service with the manage_token, or by supply parameters client_id and client_secret.

2. /banks or /providers
```http
GET /banks?expand=fields
Authorization: Bearer <token>
```
```json
{
   \"hidden\" : false,
         \"charged\" : true,
         \"name\" : \"American Express\",
         \"id\" : 30,
         \"fields\" : [
            {
               \"values\" : [
                  {
                     \"label\" : \"Particuliers/Professionnels\",
                     \"value\" : \"pp\"
                  },
                  {
                     \"value\" : \"ent\",
                     \"label\" : \"Entreprises\"
                  }
               ],
               \"label\" : \"Type de compte\",
               \"regex\" : null,
               \"name\" : \"website\",
               \"type\" : \"list\"
            },
            {
               \"type\" : \"password\",
               \"label\" : \"Code secret\",
               \"name\" : \"password\",
               \"regex\" : \"^[0-9]{6}$\"
            }
         ],
      },
      ...
   ],
   \"total\" : 44,
}
```
You get a list of connectors, and all associated fields needed to build the form at step 3.
You can also use that list to show to your user, all available banks.

3. /users/me/connections
Make a POST request and supply the id_bank (ID of the chosen bank) or id_provider (ID of provider), and all requested fields as key/value parameters.
For example:
```http
POST /users/me/connections
Authorization: Bearer <token>
-F login=12345678
-F password=123456
-F id_bank=59
```
You can get the following return codes:

|Code           |Description                                                  |
|---------------|------------------------------------------------------------ |
|200            |The connection has succeed and has been created              |
|202            |It is necessary to provide complementary information. This occurs on the first connection on some kind of Boursorama accounts for example, where a SMS is sent to the customer. It is necessary to ask the user to fill fields requested in the fields, and do a POST again on /users/me/connections/ID, with the connection ID in id_connection. |
|400            |Unable to connect to the website, the field error in the JSON can be **websiteUnavailable** or **wrongpass**  |
|403            |Invalid token                                                |

4. Activate accounts
The accounts the user wants to aggregate must be activated before any transaction or investment is retrieved.
Several accounts can be activated in 1 request by separating the account ids with commas.
```http
PUT /users/me/connections/<id_connection>/accounts/<id_account>?all
```

5. Permanent token
If the user validates the share of his accounts, it is necessary to transform the temporary code to a permanent access_token (so that the user won't expire).

To do that, make a POST request on /auth/token/access with the following parameters:
|Parameter            |Description                                                     |
|---------------------|----------------------------------------------------------------|
|code                 |The temporarily token which will let you get the access_token   |
|client_id            |The ID of your client application                               |
|client_secret        |The secret of your client application                           |

```json
POST /auth/token/access

{
   \"client_id\" : 17473055,
   \"client_secret\" : \"54tHJHjvodbANVzaRtcLzlHGXQiOgw80\",
   \"code\" : \"fBqjMZbYddebUGlkR445JKPA6pCoRaGb\"
}
```
```http
HTTP/1.1 200 OK

{
   \"access_token\" : \"7wBPuFfb1Hod82f1+KNa0AmrkIuQ3h1G\",
   \"token_type\":\"Bearer\"
}
```

### Update accounts
Another important call is when a user wants to add/remove connections to banks or providers, or to change the password on one of them, it is advised to give him a temporarily code from the permanent access_token, with the following call (using the access_token as bearer):
```http
POST /auth/token/code
Authorization: Bearer <token>
```
```json
{
   \"code\" : \"/JiDppWgbmc+5ztHIUJtHl0ynYfw682Z\",
   \"type\" : \"temporary\",
   \"expires_in\" : 1800,
}
```
Its life-time is 30 minutes, and let the browser to list connections and accounts, via `GET /users/me/connections?expand=accounts` for example.

 To update the password of a connection, you can do a POST on the *connection* resource, with the field *password* in the data. The new credentials are checked to make sure they are valid, and the return codes are the same as when adding a connection.

## Getting the data (Webhooks)
You have created your users and their connections, now it's time to get the data.
There are 2 ways to retrieve it, the 2 can be complementary:
- make regular calls to the API
- use the webhooks (recommended)

### Manual Synchronization
It is possible to do a manual synchronization of a user. We recommend to use this method in case the user wants fresh data after logging in.

To trigger the synchronization, call the API as below:
`PUT /users/ID/connections`
The following call is blocking until the synchronization is terminated.

Even if it is not recommended, it's possible to fetch synchronously new data. To do that, you can use the *expand* parameter:
` /users/ID/connections?expand=accounts[transactions,investments[type]],subscriptions`
```json
{
   \"connections\" : [
      {
         \"accounts\" : [
            {
               \"balance\" : 7481.01,
               \"currency\" : {
                  \"symbol\" : \"€\",
                  \"id\" : \"EUR\",
                  \"prefix\" : false
               },
               \"deleted\" : null,
               \"display\" : true,
               \"formatted_balance\" : \"7 481,01 €\",
               \"iban\" : \"FR76131048379405300290000016\",
               \"id\" : 17,
               \"id_connection\" : 7,
               \"investments\" : [
                  {
                     \"code\" : \"FR0010330902\",
                     \"description\" : \"\",
                     \"diff\" : -67.86,
                     \"id\" : 55,
                     \"id_account\" : 19,
                     \"id_type\" : 1,
                     \"label\" : \"Agressor PEA\",
                     \"portfolio_share\" : 0.48,
                     \"prev_diff\" : 2019.57,
                     \"quantity\" : 7.338,
                     \"type\" : {
                        \"color\" : \"AABBCC\",
                        \"id\" : 1,
                        \"name\" : \"Fonds action\"
                     },
                     \"unitprice\" : 488.98,
                     \"unitvalue\" : 479.73,
                     \"valuation\" : 3520.28
                  }
               ],
               \"last_update\" : \"2015-07-04 15:17:30\",
               \"name\" : \"Compte chèque\",
               \"number\" : \"3002900000\",
               \"transactions\" : [
                  {
                     \"active\" : true,
                     \"application_date\" : \"2015-06-17\",
                     \"coming\" : false,
                     \"comment\" : null,
                     \"commission\" : null,
                     \"country\" : null,
                     \"date\" : \"2015-06-18\",
                     \"date_scraped\" : \"2015-07-04 15:17:30\",
                     \"deleted\" : null,
                     \"documents_count\" : 0,
                     \"formatted_value\" : \"-16,22 €\",
                     \"id\" : 309,
                     \"id_account\" : 17,
                     \"id_category\" : 9998,
                     \"id_cluster\" : null,
                     \"last_update\" : \"2015-07-04 15:17:30\",
                     \"new\" : true,
                     \"original_currency\" : null,
                     \"original_value\" : null,
                     \"original_wording\" : \"FACTURE CB HALL'S BEER\",
                     \"rdate\" : \"2015-06-17\",
                     \"simplified_wording\" : \"HALL'S BEER\",
                     \"state\" : \"parsed\",
                     \"stemmed_wording\" : \"HALL'S BEER\",
                     \"type\" : \"card\",
                     \"value\" : -16.22,
                     \"wording\" : \"HALL'S BEER\"
                  }
               ],
               \"type\" : \"checking\"
            }
         ],
         \"error\" : null,
         \"expire\" : null,
         \"id\" : 7,
         \"id_user\" : 7,
         \"id_bank\" : 41,
         \"last_update\" : \"2015-07-04 15:17:31\"
      }
   ],
   \"total\" : 1,
}
```

### Background synchronizations & Webhooks
Webhooks are callbacks sent to your server, when an event is triggered during a synchronization.
Synchronizations are automatic, the frequency can be set using the configuration key `autosync.frequency`.
Using webhooks allows you to get the most up-to-date data of your users, after each synchronization.

The automatic synchronization makes it possible to recover new bank entries, or new invoices, at a given frequency.
You have the possibility to add webhooks on several events, and choose to receive each one on a distinct URL.
To see the list of available webhooks you can call the endpoint hereunder:
```
curl https://demo.biapi.pro/2.0/webhooks_events \\
  -H 'Authorization: Bearer <token>'
```

The background synchronizations for each user are independent, and their plannings are spread over the day so that they do not overload any website.

Once the synchronization of a user is over, a POST request is sent on the callback URL you have defined, including all webhook data.
A typical json sent to your server is as below:
```http
POST /callback HTTP/1.1
Host: example.org
Content-Length: 959
Accept-Encoding: gzip, deflate, compress
Accept: */*
User-Agent: Budgea API/2.0
Content-Type: application/json; charset=utf-8
Authorization: Bearer sl/wuqgD2eOo+4Zf9FjvAz3YJgU+JKsJ

{
   \"connections\" : [
      {
         \"accounts\" : [
            {
               \"balance\" : 7481.01,
               \"currency\" : {
                  \"symbol\" : \"€\",
                  \"id\" : \"EUR\",
                  \"prefix\" : false
               },
               \"deleted\" : null,
               \"display\" : true,
               \"formatted_balance\" : \"7 481,01 €\",
               \"iban\" : \"FR76131048379405300290000016\",
               \"id\" : 17,
               \"id_connection\" : 7,
               \"investments\" : [
                  {
                     \"code\" : \"FR0010330902\",
                     \"description\" : \"\",
                     \"diff\" : -67.86,
                     \"id\" : 55,
                     \"id_account\" : 19,
                     \"id_type\" : 1,
                     \"label\" : \"Agressor PEA\",
                     \"portfolio_share\" : 0.48,
                     \"prev_diff\" : 2019.57,
                     \"quantity\" : 7.338,
                     \"type\" : {
                        \"color\" : \"AABBCC\",
                        \"id\" : 1,
                        \"name\" : \"Fonds action\"
                     },
                     \"unitprice\" : 488.98,
                     \"unitvalue\" : 479.73,
                     \"valuation\" : 3520.28
                  }
               ],
               \"last_update\" : \"2015-07-04 15:17:30\",
               \"name\" : \"Compte chèque\",
               \"number\" : \"3002900000\",
               \"transactions\" : [
                  {
                     \"active\" : true,
                     \"application_date\" : \"2015-06-17\",
                     \"coming\" : false,
                     \"comment\" : null,
                     \"commission\" : null,
                     \"country\" : null,
                     \"date\" : \"2015-06-18\",
                     \"date_scraped\" : \"2015-07-04 15:17:30\",
                     \"deleted\" : null,
                     \"documents_count\" : 0,
                     \"formatted_value\" : \"-16,22 €\",
                     \"id\" : 309,
                     \"id_account\" : 17,
                     \"id_category\" : 9998,
                     \"id_cluster\" : null,
                     \"last_update\" : \"2015-07-04 15:17:30\",
                     \"new\" : true,
                     \"original_currency\" : null,
                     \"original_value\" : null,
                     \"original_wording\" : \"FACTURE CB HALL'S BEER\",
                     \"rdate\" : \"2015-06-17\",
                     \"simplified_wording\" : \"HALL'S BEER\",
                     \"state\" : \"parsed\",
                     \"stemmed_wording\" : \"HALL'S BEER\",
                     \"type\" : \"card\",
                     \"value\" : -16.22,
                     \"wording\" : \"HALL'S BEER\"
                  }
               ],
               \"type\" : \"checking\"
            }
         ],
         \"bank\" : {
            \"id_weboob\" : \"ing\",
            \"charged\" : true,
            \"name\" : \"ING Direct\",
            \"id\" : 7,
            \"hidden\" : false
         },
         \"error\" : null,
         \"expire\" : null,
         \"id\" : 7,
         \"id_user\" : 7,
         \"id_bank\" : 41,
         \"last_update\" : \"2015-07-04 15:17:31\"
      }
   ],
   \"total\" : 1,
   \"user\" : {
      \"signin\" : \"2015-07-04 15:17:29\",
      \"id\" : 7,
      \"platform\" : \"sharedAccess\"
   }
}
```
The authentication on the callback is made with the access_token of the user (which is a shared secret between your server and the Budgea API).

When you are in production, it is needed to define a HTTPS URL using a valid certificate, delivered by a recognized authority. If this is not the case, you can contact us to add your CA (Certificate Authority) to our PKI (Public Key Infrastructure).

Important: it is necessary to send back a HTTP 200 code, without what we consider that data is not correctly taken into account on your system, and it will be sent again at the next user synchronization.

## Guidelines for production
Now you should have integrated the API inside your application. Make sure your Webhooks URLs are in HTTPS, if so you can enable the production state of the API.

To make things great, here are some good practices, please check you have respected them:
- You have provided to your users a way to configure their accounts
- You have provided to your users a way to change their account passwords
- You consider the **error** field of Connections, to alert the user in case the state is **wrongpass**
- You map IDs of Accounts, Subscriptions, Transactions and Documents in your application, to be sure to correctly match them
- When the deleted field is set on a bank transaction, you delete it in your database
- You don't loop on all users to launch synchronizations, this might saturate the service

If you have questions about above points, please contact us. Otherwise, you can put into production!

### Going further
If you want to raise the bar for your app and add features such as the ability to do transfers, get invoices, aggregate patrimony and more, please refer to the sections below.
We'll discuss complementary APIs building upon the aggregation, allowing for the best of financial apps.

## Budgea API Pay
This API allows for the emition of transfers between the aggregated accounts.
Just like the simple aggregation, BI provides a webview or a protocol to follow, to implement this feature.

### API pay protocol
This section describes how the transfer and recipient protocol work, in case you don't want to integrate the webview.
The idea is to do following calls client side (with AJAX in case of a web application), so that the interaction with the Budgea API is transparent.

#### Executing a transfer
1. /auth/token/code
If you do calls client side, get a new temporary code for the user, from the access_token. This will prevent security issues.
```
curl -d '' \\
  https://demo.biapi.pro/2.0/auth/token/code \\
  -H 'Authorization: Bearer <token>'
```
```json
{
   \"code\": \"/JiDppWgbmc+5ztHIUJtHl0ynYfw682Z\",
   \"type\": \"temporary\",
   \"expires_in\": 1800
}
```
The returned token has a life-time of 30 minutes.

2. /users/me/accounts?able_to_transfer=1
List all the accounts that can do transfers. Authenticate the call with the code you got at step 1.
```
curl https://demo.biapi.pro/2.0/users/me/accounts?able_to_transfer=1 \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z'
```
```json
{
  \"accounts\" : [
      {
         \"display\" : true,
         \"balance\" : 2893.36,
         \"id_type\" : 2,
         \"number\" : \"****1572\",
         \"type\" : \"checking\",
         \"deleted\" : null,
         \"bic\" : \"BNPAFRPPXXX\",
         \"bookmarked\" : false,
         \"coming\" : -2702.74,
         \"id_user\" : 1,
         \"original_name\" : \"Compte de chèques\",
         \"currency\" : {
            \"symbol\" : \"€\",
            \"id\" : \"EUR\",
            \"prefix\" : false
         },
         \"name\" : \"lol\",
         \"iban\" : \"FR7630004012550000041157244\",
         \"last_update\" : \"2016-12-28 12:31:04\",
         \"id\" : 723,
         \"formatted_balance\" : \"2893,36 €\",
         \"able_to_transfer\" : true,
         \"id_connection\" : 202
      }
   ],
   \"total\" : 1
}
```

3. /users/me/accounts/ID/recipients
List all available recipients for a given account.
```
curl https://demo.biapi.pro/2.0/users/me/accounts/723/recipients?limit=1 \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z'
```
```json
{
  \"total\" : 27,
   \"recipients\" : [
      {
         \"bank_name\" : \"BNP PARIBAS\",
         \"bic\" : \"BNPAFRPPXXX\",
         \"category\" : \"Interne\",
         \"deleted\" : null,
         \"enabled_at\" : \"2016-10-31 18:52:53\",
         \"expire\" : null,
         \"iban\" : \"FR7630004012550003027641744\",
         \"id\" : 1,
         \"id_account\" : 1,
         \"id_target_account\" : 2,
         \"label\" : \"Livret A\",
         \"last_update\" : \"2016-12-05 12:07:24\",
         \"time_scraped\" : \"2016-10-31 18:52:54\",
         \"webid\" : \"2741588268268091098819849694548441184167285851255682796371\"
      }
   ]
}
```

4. /users/me/accounts/ID/recipients/ID/transfers
Create the transfer
```
curl \\
  https://demo.biapi.pro/2.0/users/me/accounts/1/recipients/1/transfers \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z' \\
  -F amount=10, \\
  -F label=\"Test virement\", \\
  -F exec_date=\"2018-09-12\" // optional
```
```json
{
   \"account_iban\" : \"FR7630004012550000041157244\",
   \"amount\" : 10,
   \"currency\" : {
      \"id\" : \"EUR\",
      \"prefix\" : false,
      \"symbol\" : \"€\"
   },
   \"exec_date\" : \"2018-09-12\",
   \"fees\" : null
   \"formatted_amount\" : \"10,00 €\",
   \"id\" : 22,
   \"id_account\" : 1,,
   \"id_recipient\" : 1,
   \"label\" : \"Test virement\",
   \"recipient_iban\" : \"FR7630004012550003027641744\",
   \"register_date\" : \"2018-09-12 10:34:59\",
   \"state\" : \"created\",
   \"webid\" : null
}
```

5. /users/me/transfers/ID
Execute the transfer
```
curl \\
  https://demo.biapi.pro/2.0/users/me/transfers/22 \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z' \\
  -F validated=true
```
```json
{
   \"account_iban\" : \"FR7630004012550000041157244\",
   \"amount\" : 10,
   \"currency\" : {
      \"id\" : \"EUR\",
      \"prefix\" : false,
      \"symbol\" : \"€\"
   },
   \"exec_date\" : \"2016-12-19\",
   \"fees\" : null,
   \"fields\" : [
      {
         \"label\" : \"Code secret BNP Paribas\",
         \"type\" : \"password\",
         \"regex\" : \"^[0-9]{6}$\",
         \"name\" : \"password\"
      }
   ],
   \"formatted_amount\" : \"10,00 €\",
   \"id\" : 22,
   \"id_account\" : 1,
   \"id_recipient\" : 1,
   \"label\" : \"Test virement\",
   \"recipient_iban\" : \"FR7630004012550003027641744\",
   \"register_date\" : \"2016-12-19 10:34:59\",
   \"state\" : \"created\",
   \"webid\" : null
}
```
Here, an authentication step asks user to enter his bank password. The transfer can be validated with:

```
curl \\
  https://demo.biapi.pro/2.0/users/me/transfers/22 \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z' \\
  -F validated=true \\
  -F password=\"123456\"
```
```json
{
   \"account_iban\" : \"FR7630004012550000041157244\",
   \"currency\" : {
      \"id\" : \"EUR\",
      \"prefix\" : false,
      \"symbol\" : \"€\"
   },
   \"amount\" : 10,
   \"exec_date\" : \"2016-12-19\",
   \"fees\" : 0,
   \"formatted_amount\" : \"10,00 €\",
   \"id\" : 22,
   \"id_account\" : 1,
   \"id_recipient\" : 1,
   \"label\" : \"Test virement\",
   \"recipient_iban\" : \"FR7630004012550003027641744\",
   \"register_date\" : \"2016-12-19 10:34:59\",
   \"state\" : \"pending\",
   \"webid\" : \"ZZ10C4FKSNP05TK95\"
}
```
The field state is changed to *pending*, telling that the transfer has been correctly executed on the bank. A connection synchronization is then launched, to find the bank transaction in the movements history. In this case, the transfer state will be changed to *done*.

#### Adding a recipient
1. /auth/token/code
Get a temporary token for the user. Same procedure than step 1 for a transfer.

2. /users/me/accounts?able_to_transfer=1
List accounts allowing transfers. Same procedure than step 2 for a transfer.

3. /users/me/accounts/ID/recipients/
Add a new recipient.
```
curl \\
  https://demo.biapi.pro/2.0/users/me/accounts/1/recipients \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z' \\
  -F iban=FR7613048379405300290000355 \\
  -F label=\"Papa\", \\
  -F category=\"Famille\" // optional
```
```json
{
   \"bank_name\" : \"BNP PARIBAS\",
   \"bic\" : \"BNPAFRPPXXX\",
   \"category\" : \"Famille\",
   \"deleted\" : null,
   \"enabled_at\" : null,
   \"expire\" : \"2017-04-29 16:56:20\",
   \"fields\" : [
      {
         \"label\" : \"Veuillez entrer le code reçu par SMS\",
         \"type\" : \"password\",
         \"regex\" : \"^[0-9]{6}$\",
         \"name\" : \"sms\"
      }
   ],
   \"iban\" : \"FR7613048379405300290000355\",
   \"id\" : 2,
   \"id_account\" : 1,
   \"id_target_account\" : null,
   \"label\" : \"Papa\",
   \"last_update\" : \"2017-04-29 16:26:20\",
   \"time_scraped\" : null,
   \"webid\" : null
}
```
It is necessary to post on the object Recipient with the requested fields (here sms), until the add is validated:
```
curl \\
  https://demo.biapi.pro/2.0/users/me/accounts/1/recipients/2 \\
  -H 'Authorization: Bearer /JiDppWgbmc+5ztHIUJtHl0ynYfw682Z' \\
  -F sms=\"123456\"
```
```json
{
   \"bank_name\" : \"BNP PARIBAS\",
   \"bic\" : \"BNPAFRPPXXX\",
   \"category\" : \"Famille\",
   \"deleted\" : null,
   \"enabled_at\" : \"2017-05-01 00:00:00\",
   \"expire\" : null,
   \"iban\" : \"FR7613048379405300290000355\",
   \"id\" : 2,
   \"id_account\" : 1,
   \"id_target_account\" : null,
   \"label\" : \"Papa\",
   \"last_update\" : \"2017-04-29 16:26:20\",
   \"time_scraped\" : null,
   \"webid\" : \"2741588268268091098819849694548441184167285851255682796371\"
}
```
If the field enabled_at is in the future, it means that it isn't possible yet to execute a transfer, as the bank requires to wait a validation period.

### API Pay Webview
This section describes how to integrate the webview of the Budgea Pay API inside your application, to let your users do transfers to their recipients.

#### User redirection
To redirect the user to the webview, it is necessary to build a URI authenticated with a temporary token.
This can be done from our library, or by calling the endpoint `/auth/token/code` (see the protocol section for an example).
If the parameter **redirect_uri** is supplied, the user will be redirected to that page once the transfer is done.

#### List of pages
Here are a list a pages you may call to redirect your user directly on a page of the process:
|Path                                 |Description of the page                                                           |
|-------------------------------------|----------------------------------------------------------------------------------|
|/transfers                           |List Transfers                                                                    |
|/transfers/accounts                  |List emitter accounts                                                             |
|/transfers/accounts/id/recipients    |List recipients                                                                   |
|/transfers/accounts/id/recipients/id |Initialization of a transfer between the account and the recipient                |
|/transfers/id                        |Detail of a given transfer                                                        |

## Deprecated

This section lists all the deprecated features in Budgea API. The associated date is the date of its removal.
**Do not use them**.

### Key Investments (**2019-06-24**)

Adding a temporary new key \"all_investments\" that will include deleted investments in the **webhooks**.

### No automatic expand on User objects (**2019-07-30**)
In the API responses, by default, User objects won't display the keys \"config\", \"alert_settings\" and \"invites\" anymore.
You will still be able to access this data by expanding the request.
Example: GET /users/me/?expand=alert_settings,config

### Renaming of \"type\" field for jwt tokens (**2019-07-30**)
For user's tokens in the jwt format, the \"type\" field will be renamed from \"shared_access\" to \"sharedAccess\".


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0
- Package version: 0.1.10
- Build package: eu.rienafairefr.customcodegen.PythonCustomCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/rienafairefr/pybudgea.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/rienafairefr/pybudgea.git`)

Then import the package:
```python
import budgea
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import budgea
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import budgea
from budgea.rest import ApiException
from pprint import pprint

configuration = budgea.Configuration()
# Configure API key authorization: Authorization
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# Defining host is optional and default to http://demo.biapi.pro/2.0
configuration.host = "http://demo.biapi.pro/2.0"
# Enter a context with an instance of the API client
with budgea.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = budgea.AdministrationApi(api_client)
    expand = 'expand_example' # str |  (optional)

    try:
        # List clients
        api_response = api_instance.clients_get(expand=expand)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdministrationApi->clients_get: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://demo.biapi.pro/2.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdministrationApi* | [**clients_get**](docs/AdministrationApi.md#clients_get) | **GET** /clients | List clients
*AdministrationApi* | [**clients_post**](docs/AdministrationApi.md#clients_post) | **POST** /clients | Create a client
*AdministrationApi* | [**clientsid_client_delete**](docs/AdministrationApi.md#clientsid_client_delete) | **DELETE** /clients/{id_client} | Delete a client
*AdministrationApi* | [**clientsid_client_get**](docs/AdministrationApi.md#clientsid_client_get) | **GET** /clients/{id_client} | Get information about a client
*AdministrationApi* | [**clientsid_client_logo_delete**](docs/AdministrationApi.md#clientsid_client_logo_delete) | **DELETE** /clients/{id_client}/logo | Delete the client logo
*AdministrationApi* | [**clientsid_client_logo_post**](docs/AdministrationApi.md#clientsid_client_logo_post) | **POST** /clients/{id_client}/logo | Update the client logo
*AdministrationApi* | [**clientsid_client_put**](docs/AdministrationApi.md#clientsid_client_put) | **PUT** /clients/{id_client} | Update a client
*AdministrationApi* | [**config_get**](docs/AdministrationApi.md#config_get) | **GET** /config | Get configuration of the API.
*AdministrationApi* | [**config_logs_get**](docs/AdministrationApi.md#config_logs_get) | **GET** /config/logs | Get configuration change history of the API.
*AdministrationApi* | [**config_post**](docs/AdministrationApi.md#config_post) | **POST** /config | Set a configuration value on the API.
*AdministrationApi* | [**merchants_get**](docs/AdministrationApi.md#merchants_get) | **GET** /merchants | List clients
*AdministrationApi* | [**merchants_post**](docs/AdministrationApi.md#merchants_post) | **POST** /merchants | Create a merchant. Needs a user identified in bearer to be used
*AdministrationApi* | [**merchantsid_client_logo_delete**](docs/AdministrationApi.md#merchantsid_client_logo_delete) | **DELETE** /merchants/{id_client}/logo | Delete the client logo
*AdministrationApi* | [**merchantsid_client_logo_post**](docs/AdministrationApi.md#merchantsid_client_logo_post) | **POST** /merchants/{id_client}/logo | Update the client logo
*AdministrationApi* | [**monitoring_get**](docs/AdministrationApi.md#monitoring_get) | **GET** /monitoring | get performances stats on this instance
*AdministrationApi* | [**test_sync_post**](docs/AdministrationApi.md#test_sync_post) | **POST** /test/sync | Test synchronization on a random connection.
*AdministrationApi* | [**test_webhooks_post**](docs/AdministrationApi.md#test_webhooks_post) | **POST** /test/webhooks | Test synchronization on a random connection.
*AdministrationApi* | [**webhooks_auth_delete**](docs/AdministrationApi.md#webhooks_auth_delete) | **DELETE** /webhooks/auth | Deletes all webhook authentication types
*AdministrationApi* | [**webhooks_auth_get**](docs/AdministrationApi.md#webhooks_auth_get) | **GET** /webhooks/auth | Get webhooks authentication types
*AdministrationApi* | [**webhooks_auth_post**](docs/AdministrationApi.md#webhooks_auth_post) | **POST** /webhooks/auth | Adds a new webhook authentication type
*AdministrationApi* | [**webhooks_authid_auth_delete**](docs/AdministrationApi.md#webhooks_authid_auth_delete) | **DELETE** /webhooks/auth/{id_auth} | Deletes the webhook authentication type
*AdministrationApi* | [**webhooks_authid_auth_post**](docs/AdministrationApi.md#webhooks_authid_auth_post) | **POST** /webhooks/auth/{id_auth} | Updates the webhook authentication type
*AdministrationApi* | [**webhooks_authid_auth_put**](docs/AdministrationApi.md#webhooks_authid_auth_put) | **PUT** /webhooks/auth/{id_auth} | Updates the webhook authentication type
*AdministrationApi* | [**webhooks_delete**](docs/AdministrationApi.md#webhooks_delete) | **DELETE** /webhooks | Deletes all webhooks
*AdministrationApi* | [**webhooks_get**](docs/AdministrationApi.md#webhooks_get) | **GET** /webhooks | Get webhooks
*AdministrationApi* | [**webhooks_post**](docs/AdministrationApi.md#webhooks_post) | **POST** /webhooks | Adds a new webhook
*AdministrationApi* | [**webhooksid_webhook_add_to_data_delete**](docs/AdministrationApi.md#webhooksid_webhook_add_to_data_delete) | **DELETE** /webhooks/{id_webhook}/add_to_data | delete all entries
*AdministrationApi* | [**webhooksid_webhook_add_to_data_get**](docs/AdministrationApi.md#webhooksid_webhook_add_to_data_get) | **GET** /webhooks/{id_webhook}/add_to_data | retrieve the list of the value to add in webhooks when sending the requested webhook
*AdministrationApi* | [**webhooksid_webhook_add_to_data_post**](docs/AdministrationApi.md#webhooksid_webhook_add_to_data_post) | **POST** /webhooks/{id_webhook}/add_to_data | Setup a field to store in user config when calling the endpoint
*AdministrationApi* | [**webhooksid_webhook_add_to_datakey_delete**](docs/AdministrationApi.md#webhooksid_webhook_add_to_datakey_delete) | **DELETE** /webhooks/{id_webhook}/add_to_data/{key} | delete the requested entry
*AdministrationApi* | [**webhooksid_webhook_add_to_datakey_get**](docs/AdministrationApi.md#webhooksid_webhook_add_to_datakey_get) | **GET** /webhooks/{id_webhook}/add_to_data/{key} | retrieve the value to add in the requested webhook for the requested name
*AdministrationApi* | [**webhooksid_webhook_add_to_datakey_post**](docs/AdministrationApi.md#webhooksid_webhook_add_to_datakey_post) | **POST** /webhooks/{id_webhook}/add_to_data/{key} | upate the requested field to store in user config when calling the endpoint
*AdministrationApi* | [**webhooksid_webhook_delete**](docs/AdministrationApi.md#webhooksid_webhook_delete) | **DELETE** /webhooks/{id_webhook} | Deletes a webhook
*AdministrationApi* | [**webhooksid_webhook_logs_get**](docs/AdministrationApi.md#webhooksid_webhook_logs_get) | **GET** /webhooks/{id_webhook}/logs | Get webhooks logs.
*AdministrationApi* | [**webhooksid_webhook_post**](docs/AdministrationApi.md#webhooksid_webhook_post) | **POST** /webhooks/{id_webhook} | Updates a webhook
*AdministrationApi* | [**webhooksid_webhook_put**](docs/AdministrationApi.md#webhooksid_webhook_put) | **PUT** /webhooks/{id_webhook} | Updates a webhook
*AuthenticationApi* | [**admin_jwt_post**](docs/AuthenticationApi.md#admin_jwt_post) | **POST** /admin/jwt | Generate a jwt manage token
*AuthenticationApi* | [**auth_init_post**](docs/AuthenticationApi.md#auth_init_post) | **POST** /auth/init | Create a new anonymous user
*AuthenticationApi* | [**auth_jwt_post**](docs/AuthenticationApi.md#auth_jwt_post) | **POST** /auth/jwt | Generate a user jwt token
*AuthenticationApi* | [**auth_token_access_post**](docs/AuthenticationApi.md#auth_token_access_post) | **POST** /auth/token/access | Transform a temporary code to a access_token
*AuthenticationApi* | [**auth_token_code_get**](docs/AuthenticationApi.md#auth_token_code_get) | **GET** /auth/token/code | Generate a user temporary token
*AuthenticationApi* | [**auth_token_delete**](docs/AuthenticationApi.md#auth_token_delete) | **DELETE** /auth/token | Remove user access
*AuthenticationApi* | [**certificatetype_get**](docs/AuthenticationApi.md#certificatetype_get) | **GET** /certificate/{type} | Get the latest certificate of a type
*AuthenticationApi* | [**hash_delete**](docs/AuthenticationApi.md#hash_delete) | **DELETE** /hash | Delete the user&#39;s connections
*AuthenticationApi* | [**usersid_user_delete**](docs/AuthenticationApi.md#usersid_user_delete) | **DELETE** /users/{id_user} | Delete the user
*AuthenticationApi* | [**usersid_user_get**](docs/AuthenticationApi.md#usersid_user_get) | **GET** /users/{id_user} | Get a user
*AuthenticationApi* | [**usersid_user_token_post**](docs/AuthenticationApi.md#usersid_user_token_post) | **POST** /users/{id_user}/token | Create a token
*AuthenticationApi* | [**webauth_get**](docs/AuthenticationApi.md#webauth_get) | **GET** /webauth | First step to establish an oAuth2 connection.
*BanksApi* | [**account_types_get**](docs/BanksApi.md#account_types_get) | **GET** /account_types | Get account types
*BanksApi* | [**account_typesid_account_type_get**](docs/BanksApi.md#account_typesid_account_type_get) | **GET** /account_types/{id_account_type} | Get an account type
*BanksApi* | [**banks_categories_post**](docs/BanksApi.md#banks_categories_post) | **POST** /banks/categories | Create bank categories
*BanksApi* | [**banks_categoriesid_category_delete**](docs/BanksApi.md#banks_categoriesid_category_delete) | **DELETE** /banks/categories/{id_category} | Delete the supplied category
*BanksApi* | [**banks_categoriesid_category_post**](docs/BanksApi.md#banks_categoriesid_category_post) | **POST** /banks/categories/{id_category} | Edit a bank categories
*BanksApi* | [**banks_get**](docs/BanksApi.md#banks_get) | **GET** /banks | Get list of connectors
*BanksApi* | [**banksid_connector_connections_get**](docs/BanksApi.md#banksid_connector_connections_get) | **GET** /banks/{id_connector}/connections | Get a subset of id_connection with the largest diversity of account
*BanksApi* | [**banksid_connector_logos_get**](docs/BanksApi.md#banksid_connector_logos_get) | **GET** /banks/{id_connector}/logos | Get all links to the files associated with this connector.
*BanksApi* | [**banksid_connector_logos_main_get**](docs/BanksApi.md#banksid_connector_logos_main_get) | **GET** /banks/{id_connector}/logos/main | Get all links to the files associated with this connector.
*BanksApi* | [**banksid_connector_logos_thumbnail_get**](docs/BanksApi.md#banksid_connector_logos_thumbnail_get) | **GET** /banks/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*BanksApi* | [**banksid_connector_sources_get**](docs/BanksApi.md#banksid_connector_sources_get) | **GET** /banks/{id_connector}/sources | Get list of connector sources
*BanksApi* | [**categories_get**](docs/BanksApi.md#categories_get) | **GET** /categories | Get all categories
*BanksApi* | [**categories_keywords_post**](docs/BanksApi.md#categories_keywords_post) | **POST** /categories/keywords | Add a new keyword associated with a category in the database.
*BanksApi* | [**categories_keywordsid_keyword_delete**](docs/BanksApi.md#categories_keywordsid_keyword_delete) | **DELETE** /categories/keywords/{id_keyword} | Delete a particular key-value pair on a transaction.
*BanksApi* | [**categorize_post**](docs/BanksApi.md#categorize_post) | **POST** /categorize | categorize transactions without storing them
*BanksApi* | [**connections_get**](docs/BanksApi.md#connections_get) | **GET** /connections | Get connections without a user
*BanksApi* | [**connectionsid_connection_logs_get**](docs/BanksApi.md#connectionsid_connection_logs_get) | **GET** /connections/{id_connection}/logs | Get connection logs
*BanksApi* | [**connectionsid_connection_sources_get**](docs/BanksApi.md#connectionsid_connection_sources_get) | **GET** /connections/{id_connection}/sources | Get connection sources
*BanksApi* | [**connectionsid_connection_sourcesid_source_delete**](docs/BanksApi.md#connectionsid_connection_sourcesid_source_delete) | **DELETE** /connections/{id_connection}/sources/{id_source} | Disable a connection source
*BanksApi* | [**connectionsid_connection_sourcesid_source_post**](docs/BanksApi.md#connectionsid_connection_sourcesid_source_post) | **POST** /connections/{id_connection}/sources/{id_source} | Enable connection source
*BanksApi* | [**connectionsid_connection_sourcesid_source_put**](docs/BanksApi.md#connectionsid_connection_sourcesid_source_put) | **PUT** /connections/{id_connection}/sources/{id_source} | Enable connection source
*BanksApi* | [**connectors_get**](docs/BanksApi.md#connectors_get) | **GET** /connectors | Get list of connectors
*BanksApi* | [**connectors_post**](docs/BanksApi.md#connectors_post) | **POST** /connectors | Request a new connector
*BanksApi* | [**connectors_put**](docs/BanksApi.md#connectors_put) | **PUT** /connectors | Enable/disable several connectors
*BanksApi* | [**connectorsid_connector_logos_get**](docs/BanksApi.md#connectorsid_connector_logos_get) | **GET** /connectors/{id_connector}/logos | Get all links to the files associated with this connector.
*BanksApi* | [**connectorsid_connector_logos_main_get**](docs/BanksApi.md#connectorsid_connector_logos_main_get) | **GET** /connectors/{id_connector}/logos/main | Get all links to the files associated with this connector.
*BanksApi* | [**connectorsid_connector_logos_post**](docs/BanksApi.md#connectorsid_connector_logos_post) | **POST** /connectors/{id_connector}/logos | Create a connector Logo
*BanksApi* | [**connectorsid_connector_logos_put**](docs/BanksApi.md#connectorsid_connector_logos_put) | **PUT** /connectors/{id_connector}/logos | Create or Update a connector Logo
*BanksApi* | [**connectorsid_connector_logos_thumbnail_get**](docs/BanksApi.md#connectorsid_connector_logos_thumbnail_get) | **GET** /connectors/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*BanksApi* | [**connectorsid_connector_logosid_logo_delete**](docs/BanksApi.md#connectorsid_connector_logosid_logo_delete) | **DELETE** /connectors/{id_connector}/logos/{id_logo} | Delete a single Logo object.
*BanksApi* | [**connectorsid_connector_logosid_logo_put**](docs/BanksApi.md#connectorsid_connector_logosid_logo_put) | **PUT** /connectors/{id_connector}/logos/{id_logo} | Create or Update a connector Logo.
*BanksApi* | [**connectorsid_connector_put**](docs/BanksApi.md#connectorsid_connector_put) | **PUT** /connectors/{id_connector} | Edit the provided connector
*BanksApi* | [**connectorsid_connector_sources_get**](docs/BanksApi.md#connectorsid_connector_sources_get) | **GET** /connectors/{id_connector}/sources | Get list of connector sources
*BanksApi* | [**connectorsid_connector_sourcesid_source_put**](docs/BanksApi.md#connectorsid_connector_sourcesid_source_put) | **PUT** /connectors/{id_connector}/sources/{id_source} | Edit the provided connector source
*BanksApi* | [**invoicing_get**](docs/BanksApi.md#invoicing_get) | **GET** /invoicing | Get invoicing data for a given period (default is the current month).
*BanksApi* | [**logs_get**](docs/BanksApi.md#logs_get) | **GET** /logs | Get connection logs
*BanksApi* | [**providers_get**](docs/BanksApi.md#providers_get) | **GET** /providers | Get list of connectors
*BanksApi* | [**providersid_connector_connections_get**](docs/BanksApi.md#providersid_connector_connections_get) | **GET** /providers/{id_connector}/connections | Get a random subset of provider&#39;s id_connection
*BanksApi* | [**providersid_connector_logos_get**](docs/BanksApi.md#providersid_connector_logos_get) | **GET** /providers/{id_connector}/logos | Get all links to the files associated with this connector.
*BanksApi* | [**providersid_connector_logos_main_get**](docs/BanksApi.md#providersid_connector_logos_main_get) | **GET** /providers/{id_connector}/logos/main | Get all links to the files associated with this connector.
*BanksApi* | [**providersid_connector_logos_thumbnail_get**](docs/BanksApi.md#providersid_connector_logos_thumbnail_get) | **GET** /providers/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*BanksApi* | [**providersid_connector_sources_get**](docs/BanksApi.md#providersid_connector_sources_get) | **GET** /providers/{id_connector}/sources | Get list of connector sources
*BanksApi* | [**usersid_user_account_types_get**](docs/BanksApi.md#usersid_user_account_types_get) | **GET** /users/{id_user}/account_types | Get account types
*BanksApi* | [**usersid_user_account_typesid_account_type_get**](docs/BanksApi.md#usersid_user_account_typesid_account_type_get) | **GET** /users/{id_user}/account_types/{id_account_type} | Get an account type
*BanksApi* | [**usersid_user_accounts_delete**](docs/BanksApi.md#usersid_user_accounts_delete) | **DELETE** /users/{id_user}/accounts | Delete all accounts
*BanksApi* | [**usersid_user_accounts_get**](docs/BanksApi.md#usersid_user_accounts_get) | **GET** /users/{id_user}/accounts | Get accounts list.
*BanksApi* | [**usersid_user_accounts_post**](docs/BanksApi.md#usersid_user_accounts_post) | **POST** /users/{id_user}/accounts | Create an account
*BanksApi* | [**usersid_user_accounts_put**](docs/BanksApi.md#usersid_user_accounts_put) | **PUT** /users/{id_user}/accounts | Update many accounts at once
*BanksApi* | [**usersid_user_accountsid_account_categories_get**](docs/BanksApi.md#usersid_user_accountsid_account_categories_get) | **GET** /users/{id_user}/accounts/{id_account}/categories | Get the category
*BanksApi* | [**usersid_user_accountsid_account_delete**](docs/BanksApi.md#usersid_user_accountsid_account_delete) | **DELETE** /users/{id_user}/accounts/{id_account} | Delete an account.
*BanksApi* | [**usersid_user_accountsid_account_delta_get**](docs/BanksApi.md#usersid_user_accountsid_account_delta_get) | **GET** /users/{id_user}/accounts/{id_account}/delta | Get deltas of accounts
*BanksApi* | [**usersid_user_accountsid_account_logs_get**](docs/BanksApi.md#usersid_user_accountsid_account_logs_get) | **GET** /users/{id_user}/accounts/{id_account}/logs | Get accounts logs.
*BanksApi* | [**usersid_user_accountsid_account_put**](docs/BanksApi.md#usersid_user_accountsid_account_put) | **PUT** /users/{id_user}/accounts/{id_account} | Update an account
*BanksApi* | [**usersid_user_accountsid_account_sources_get**](docs/BanksApi.md#usersid_user_accountsid_account_sources_get) | **GET** /users/{id_user}/accounts/{id_account}/sources | Get account sources
*BanksApi* | [**usersid_user_accountsid_account_transactions_delete**](docs/BanksApi.md#usersid_user_accountsid_account_transactions_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions | Delete transactions
*BanksApi* | [**usersid_user_accountsid_account_transactions_get**](docs/BanksApi.md#usersid_user_accountsid_account_transactions_get) | **GET** /users/{id_user}/accounts/{id_account}/transactions | Get transactions
*BanksApi* | [**usersid_user_accountsid_account_transactions_post**](docs/BanksApi.md#usersid_user_accountsid_account_transactions_post) | **POST** /users/{id_user}/accounts/{id_account}/transactions | Create transactions
*BanksApi* | [**usersid_user_accountsid_account_transactionsclusters_get**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsclusters_get) | **GET** /users/{id_user}/accounts/{id_account}/transactionsclusters | Get clustered transactions
*BanksApi* | [**usersid_user_accountsid_account_transactionsclusters_post**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsclusters_post) | **POST** /users/{id_user}/accounts/{id_account}/transactionsclusters | Create clustered transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactionscluster_delete**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsclustersid_transactionscluster_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactionscluster} | Delete a clustered transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactionscluster_put**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsclustersid_transactionscluster_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactionscluster} | Edit a clustered transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_informations_delete**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_informations_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/informations | Delete all arbitrary key-value pairs of a transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_informations_get**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_informations_get) | **GET** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/informations | List all arbitrary key-value pairs on a transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_informations_put**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_informations_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/informations | Add or edit transaction arbitrary key-value pairs
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_informationsid_information_delete**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_informationsid_information_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/informations/{id_information} | Delete a particular key-value pair on a transaction.
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_informationsid_information_get**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_informationsid_information_get) | **GET** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/informations/{id_information} | Get a particular arbitrary key-value pair on a transaction
*BanksApi* | [**usersid_user_accountsid_account_transactionsid_transaction_put**](docs/BanksApi.md#usersid_user_accountsid_account_transactionsid_transaction_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction} | Edit a transaction meta-data
*BanksApi* | [**usersid_user_alerts_get**](docs/BanksApi.md#usersid_user_alerts_get) | **GET** /users/{id_user}/alerts | Get alerts
*BanksApi* | [**usersid_user_categories_full_get**](docs/BanksApi.md#usersid_user_categories_full_get) | **GET** /users/{id_user}/categories/full | Get the category
*BanksApi* | [**usersid_user_categories_full_post**](docs/BanksApi.md#usersid_user_categories_full_post) | **POST** /users/{id_user}/categories/full | Create a new transaction category
*BanksApi* | [**usersid_user_categories_fullid_full_delete**](docs/BanksApi.md#usersid_user_categories_fullid_full_delete) | **DELETE** /users/{id_user}/categories/full/{id_full} | Delete a user-created transaction category
*BanksApi* | [**usersid_user_categories_fullid_full_put**](docs/BanksApi.md#usersid_user_categories_fullid_full_put) | **PUT** /users/{id_user}/categories/full/{id_full} | Modify a user-created category
*BanksApi* | [**usersid_user_categories_get**](docs/BanksApi.md#usersid_user_categories_get) | **GET** /users/{id_user}/categories | Get the category
*BanksApi* | [**usersid_user_connections_delete**](docs/BanksApi.md#usersid_user_connections_delete) | **DELETE** /users/{id_user}/connections | Delete all connections
*BanksApi* | [**usersid_user_connections_get**](docs/BanksApi.md#usersid_user_connections_get) | **GET** /users/{id_user}/connections | Get connections
*BanksApi* | [**usersid_user_connections_post**](docs/BanksApi.md#usersid_user_connections_post) | **POST** /users/{id_user}/connections | Add a new connection.
*BanksApi* | [**usersid_user_connectionsid_connection_accounts_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accounts_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts | Delete all accounts
*BanksApi* | [**usersid_user_connectionsid_connection_accounts_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accounts_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts | Get accounts list.
*BanksApi* | [**usersid_user_connectionsid_connection_accounts_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_accounts_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts | Create an account
*BanksApi* | [**usersid_user_connectionsid_connection_accounts_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_accounts_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts | Update many accounts at once
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_categories_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_categories_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/categories | Get the category
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account} | Delete an account.
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_delta_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_delta_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/delta | Get deltas of accounts
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_logs_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_logs_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/logs | Get accounts logs.
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account} | Update an account
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_sources_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_sources_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/sources | Get account sources
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactions_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactions_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions | Delete transactions
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactions_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactions_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions | Get transactions
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactions_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactions_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions | Create transactions
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclusters_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclusters_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters | Get clustered transactions
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclusters_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclusters_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters | Create clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactionscluster_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactionscluster_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactionscluster} | Delete a clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactionscluster_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactionscluster_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactionscluster} | Edit a clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/informations | Delete all arbitrary key-value pairs of a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/informations | List all arbitrary key-value pairs on a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informations_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/informations | Add or edit transaction arbitrary key-value pairs
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informationsid_information_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informationsid_information_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/informations/{id_information} | Delete a particular key-value pair on a transaction.
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informationsid_information_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_informationsid_information_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/informations/{id_information} | Get a particular arbitrary key-value pair on a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction} | Edit a transaction meta-data
*BanksApi* | [**usersid_user_connectionsid_connection_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_delete) | **DELETE** /users/{id_user}/connections/{id_connection} | Delete a connection.
*BanksApi* | [**usersid_user_connectionsid_connection_informations_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_informations_get) | **GET** /users/{id_user}/connections/{id_connection}/informations | Get connection additionnal informations
*BanksApi* | [**usersid_user_connectionsid_connection_logs_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_logs_get) | **GET** /users/{id_user}/connections/{id_connection}/logs | Get connection logs
*BanksApi* | [**usersid_user_connectionsid_connection_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_post) | **POST** /users/{id_user}/connections/{id_connection} | Update a connection.
*BanksApi* | [**usersid_user_connectionsid_connection_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_put) | **PUT** /users/{id_user}/connections/{id_connection} | Force synchronisation of a connection.
*BanksApi* | [**usersid_user_connectionsid_connection_sources_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_sources_get) | **GET** /users/{id_user}/connections/{id_connection}/sources | Get connection sources
*BanksApi* | [**usersid_user_connectionsid_connection_sourcesid_source_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_sourcesid_source_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Disable a connection source
*BanksApi* | [**usersid_user_connectionsid_connection_sourcesid_source_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_sourcesid_source_post) | **POST** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*BanksApi* | [**usersid_user_connectionsid_connection_sourcesid_source_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_sourcesid_source_put) | **PUT** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*BanksApi* | [**usersid_user_connectionsid_connection_transactions_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactions_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions | Delete transactions
*BanksApi* | [**usersid_user_connectionsid_connection_transactions_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactions_get) | **GET** /users/{id_user}/connections/{id_connection}/transactions | Get transactions
*BanksApi* | [**usersid_user_connectionsid_connection_transactions_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactions_post) | **POST** /users/{id_user}/connections/{id_connection}/transactions | Create transactions
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsclusters_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsclusters_get) | **GET** /users/{id_user}/connections/{id_connection}/transactionsclusters | Get clustered transactions
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsclusters_post**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsclusters_post) | **POST** /users/{id_user}/connections/{id_connection}/transactionsclusters | Create clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactionscluster_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactionscluster_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactionscluster} | Delete a clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactionscluster_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactionscluster_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactionscluster} | Edit a clustered transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_informations_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_informations_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/informations | Delete all arbitrary key-value pairs of a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_informations_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_informations_get) | **GET** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/informations | List all arbitrary key-value pairs on a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_informations_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_informations_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/informations | Add or edit transaction arbitrary key-value pairs
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_informationsid_information_delete**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_informationsid_information_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/informations/{id_information} | Delete a particular key-value pair on a transaction.
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_informationsid_information_get**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_informationsid_information_get) | **GET** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/informations/{id_information} | Get a particular arbitrary key-value pair on a transaction
*BanksApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_put**](docs/BanksApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction} | Edit a transaction meta-data
*BanksApi* | [**usersid_user_forecast_get**](docs/BanksApi.md#usersid_user_forecast_get) | **GET** /users/{id_user}/forecast | Get forecast
*BanksApi* | [**usersid_user_logs_get**](docs/BanksApi.md#usersid_user_logs_get) | **GET** /users/{id_user}/logs | Get connection logs
*BanksApi* | [**usersid_user_transactions_delete**](docs/BanksApi.md#usersid_user_transactions_delete) | **DELETE** /users/{id_user}/transactions | Delete transactions
*BanksApi* | [**usersid_user_transactions_get**](docs/BanksApi.md#usersid_user_transactions_get) | **GET** /users/{id_user}/transactions | Get transactions
*BanksApi* | [**usersid_user_transactions_post**](docs/BanksApi.md#usersid_user_transactions_post) | **POST** /users/{id_user}/transactions | Create transactions
*BanksApi* | [**usersid_user_transactionsclusters_get**](docs/BanksApi.md#usersid_user_transactionsclusters_get) | **GET** /users/{id_user}/transactionsclusters | Get clustered transactions
*BanksApi* | [**usersid_user_transactionsclusters_post**](docs/BanksApi.md#usersid_user_transactionsclusters_post) | **POST** /users/{id_user}/transactionsclusters | Create clustered transaction
*BanksApi* | [**usersid_user_transactionsclustersid_transactionscluster_delete**](docs/BanksApi.md#usersid_user_transactionsclustersid_transactionscluster_delete) | **DELETE** /users/{id_user}/transactionsclusters/{id_transactionscluster} | Delete a clustered transaction
*BanksApi* | [**usersid_user_transactionsclustersid_transactionscluster_put**](docs/BanksApi.md#usersid_user_transactionsclustersid_transactionscluster_put) | **PUT** /users/{id_user}/transactionsclusters/{id_transactionscluster} | Edit a clustered transaction
*BanksApi* | [**usersid_user_transactionsid_transaction_informations_delete**](docs/BanksApi.md#usersid_user_transactionsid_transaction_informations_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/informations | Delete all arbitrary key-value pairs of a transaction
*BanksApi* | [**usersid_user_transactionsid_transaction_informations_get**](docs/BanksApi.md#usersid_user_transactionsid_transaction_informations_get) | **GET** /users/{id_user}/transactions/{id_transaction}/informations | List all arbitrary key-value pairs on a transaction
*BanksApi* | [**usersid_user_transactionsid_transaction_informations_put**](docs/BanksApi.md#usersid_user_transactionsid_transaction_informations_put) | **PUT** /users/{id_user}/transactions/{id_transaction}/informations | Add or edit transaction arbitrary key-value pairs
*BanksApi* | [**usersid_user_transactionsid_transaction_informationsid_information_delete**](docs/BanksApi.md#usersid_user_transactionsid_transaction_informationsid_information_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/informations/{id_information} | Delete a particular key-value pair on a transaction.
*BanksApi* | [**usersid_user_transactionsid_transaction_informationsid_information_get**](docs/BanksApi.md#usersid_user_transactionsid_transaction_informationsid_information_get) | **GET** /users/{id_user}/transactions/{id_transaction}/informations/{id_information} | Get a particular arbitrary key-value pair on a transaction
*BanksApi* | [**usersid_user_transactionsid_transaction_put**](docs/BanksApi.md#usersid_user_transactionsid_transaction_put) | **PUT** /users/{id_user}/transactions/{id_transaction} | Edit a transaction meta-data
*ConnectionsApi* | [**banks_get**](docs/ConnectionsApi.md#banks_get) | **GET** /banks | Get list of connectors
*ConnectionsApi* | [**banksid_connector_connections_get**](docs/ConnectionsApi.md#banksid_connector_connections_get) | **GET** /banks/{id_connector}/connections | Get a subset of id_connection with the largest diversity of account
*ConnectionsApi* | [**banksid_connector_sources_get**](docs/ConnectionsApi.md#banksid_connector_sources_get) | **GET** /banks/{id_connector}/sources | Get list of connector sources
*ConnectionsApi* | [**connections_get**](docs/ConnectionsApi.md#connections_get) | **GET** /connections | Get connections without a user
*ConnectionsApi* | [**connectionsid_connection_logs_get**](docs/ConnectionsApi.md#connectionsid_connection_logs_get) | **GET** /connections/{id_connection}/logs | Get connection logs
*ConnectionsApi* | [**connectionsid_connection_sources_get**](docs/ConnectionsApi.md#connectionsid_connection_sources_get) | **GET** /connections/{id_connection}/sources | Get connection sources
*ConnectionsApi* | [**connectionsid_connection_sourcesid_source_delete**](docs/ConnectionsApi.md#connectionsid_connection_sourcesid_source_delete) | **DELETE** /connections/{id_connection}/sources/{id_source} | Disable a connection source
*ConnectionsApi* | [**connectionsid_connection_sourcesid_source_post**](docs/ConnectionsApi.md#connectionsid_connection_sourcesid_source_post) | **POST** /connections/{id_connection}/sources/{id_source} | Enable connection source
*ConnectionsApi* | [**connectionsid_connection_sourcesid_source_put**](docs/ConnectionsApi.md#connectionsid_connection_sourcesid_source_put) | **PUT** /connections/{id_connection}/sources/{id_source} | Enable connection source
*ConnectionsApi* | [**connectors_get**](docs/ConnectionsApi.md#connectors_get) | **GET** /connectors | Get list of connectors
*ConnectionsApi* | [**connectors_post**](docs/ConnectionsApi.md#connectors_post) | **POST** /connectors | Request a new connector
*ConnectionsApi* | [**connectorsid_connector_sources_get**](docs/ConnectionsApi.md#connectorsid_connector_sources_get) | **GET** /connectors/{id_connector}/sources | Get list of connector sources
*ConnectionsApi* | [**connectorsid_connector_sourcesid_source_put**](docs/ConnectionsApi.md#connectorsid_connector_sourcesid_source_put) | **PUT** /connectors/{id_connector}/sources/{id_source} | Edit the provided connector source
*ConnectionsApi* | [**logs_get**](docs/ConnectionsApi.md#logs_get) | **GET** /logs | Get connection logs
*ConnectionsApi* | [**providers_get**](docs/ConnectionsApi.md#providers_get) | **GET** /providers | Get list of connectors
*ConnectionsApi* | [**providersid_connector_connections_get**](docs/ConnectionsApi.md#providersid_connector_connections_get) | **GET** /providers/{id_connector}/connections | Get a random subset of provider&#39;s id_connection
*ConnectionsApi* | [**providersid_connector_sources_get**](docs/ConnectionsApi.md#providersid_connector_sources_get) | **GET** /providers/{id_connector}/sources | Get list of connector sources
*ConnectionsApi* | [**usersid_user_connections_delete**](docs/ConnectionsApi.md#usersid_user_connections_delete) | **DELETE** /users/{id_user}/connections | Delete all connections
*ConnectionsApi* | [**usersid_user_connections_get**](docs/ConnectionsApi.md#usersid_user_connections_get) | **GET** /users/{id_user}/connections | Get connections
*ConnectionsApi* | [**usersid_user_connections_post**](docs/ConnectionsApi.md#usersid_user_connections_post) | **POST** /users/{id_user}/connections | Add a new connection.
*ConnectionsApi* | [**usersid_user_connectionsid_connection_delete**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_delete) | **DELETE** /users/{id_user}/connections/{id_connection} | Delete a connection.
*ConnectionsApi* | [**usersid_user_connectionsid_connection_informations_get**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_informations_get) | **GET** /users/{id_user}/connections/{id_connection}/informations | Get connection additionnal informations
*ConnectionsApi* | [**usersid_user_connectionsid_connection_logs_get**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_logs_get) | **GET** /users/{id_user}/connections/{id_connection}/logs | Get connection logs
*ConnectionsApi* | [**usersid_user_connectionsid_connection_post**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_post) | **POST** /users/{id_user}/connections/{id_connection} | Update a connection.
*ConnectionsApi* | [**usersid_user_connectionsid_connection_put**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_put) | **PUT** /users/{id_user}/connections/{id_connection} | Force synchronisation of a connection.
*ConnectionsApi* | [**usersid_user_connectionsid_connection_sources_get**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_sources_get) | **GET** /users/{id_user}/connections/{id_connection}/sources | Get connection sources
*ConnectionsApi* | [**usersid_user_connectionsid_connection_sourcesid_source_delete**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_sourcesid_source_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Disable a connection source
*ConnectionsApi* | [**usersid_user_connectionsid_connection_sourcesid_source_post**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_sourcesid_source_post) | **POST** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*ConnectionsApi* | [**usersid_user_connectionsid_connection_sourcesid_source_put**](docs/ConnectionsApi.md#usersid_user_connectionsid_connection_sourcesid_source_put) | **PUT** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*ConnectionsApi* | [**usersid_user_logs_get**](docs/ConnectionsApi.md#usersid_user_logs_get) | **GET** /users/{id_user}/logs | Get connection logs
*DocumentsApi* | [**documenttypes_get**](docs/DocumentsApi.md#documenttypes_get) | **GET** /documenttypes | Get document types
*DocumentsApi* | [**documenttypesid_documenttype_put**](docs/DocumentsApi.md#documenttypesid_documenttype_put) | **PUT** /documenttypes/{id_documenttype} | Edit a document type
*DocumentsApi* | [**ocr_post**](docs/DocumentsApi.md#ocr_post) | **POST** /ocr | Post an image with OCR
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_get**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_post**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_put**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_delete**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Delete documents
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_get**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Get documents
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_post**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Add a new document
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_put**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Delete documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_get**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Get documents
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_post**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Add a new document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_documents_delete**](docs/DocumentsApi.md#usersid_user_documents_delete) | **DELETE** /users/{id_user}/documents | Delete documents
*DocumentsApi* | [**usersid_user_documents_get**](docs/DocumentsApi.md#usersid_user_documents_get) | **GET** /users/{id_user}/documents | Get documents
*DocumentsApi* | [**usersid_user_documents_post**](docs/DocumentsApi.md#usersid_user_documents_post) | **POST** /users/{id_user}/documents | Add a new document
*DocumentsApi* | [**usersid_user_documents_put**](docs/DocumentsApi.md#usersid_user_documents_put) | **PUT** /users/{id_user}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_documentsid_document_delete) | **DELETE** /users/{id_user}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_documentsid_document_put) | **PUT** /users/{id_user}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_ocr_post**](docs/DocumentsApi.md#usersid_user_ocr_post) | **POST** /users/{id_user}/ocr | Post an image with OCR
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documents_delete**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documents_delete) | **DELETE** /users/{id_user}/subscriptions/{id_subscription}/documents | Delete documents
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documents_get**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documents_get) | **GET** /users/{id_user}/subscriptions/{id_subscription}/documents | Get documents
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documents_post**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documents_post) | **POST** /users/{id_user}/subscriptions/{id_subscription}/documents | Add a new document
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documents_put**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documents_put) | **PUT** /users/{id_user}/subscriptions/{id_subscription}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documentsid_document_delete) | **DELETE** /users/{id_user}/subscriptions/{id_subscription}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_subscriptionsid_subscription_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_subscriptionsid_subscription_documentsid_document_put) | **PUT** /users/{id_user}/subscriptions/{id_subscription}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_delete**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_get**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_post**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_put**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documents_delete**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/documents | Delete documents
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documents_get**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/transactions/{id_transaction}/documents | Get documents
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documents_post**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/transactions/{id_transaction}/documents | Add a new document
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documents_put**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documentsid_document_delete**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*DocumentsApi* | [**usersid_user_transactionsid_transaction_documentsid_document_put**](docs/DocumentsApi.md#usersid_user_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*OCRApi* | [**ocr_post**](docs/OCRApi.md#ocr_post) | **POST** /ocr | Post an image with OCR
*OCRApi* | [**usersid_user_ocr_post**](docs/OCRApi.md#usersid_user_ocr_post) | **POST** /users/{id_user}/ocr | Post an image with OCR
*OIDCApi* | [**oidc_whitelist_post**](docs/OIDCApi.md#oidc_whitelist_post) | **POST** /oidc/whitelist | Adds an authorized redirect uri
*OIDCApi* | [**oidc_whitelistid_whitelist_delete**](docs/OIDCApi.md#oidc_whitelistid_whitelist_delete) | **DELETE** /oidc/whitelist/{id_whitelist} | Delete the supplied authorized redirect uri
*OIDCApi* | [**oidc_whitelistid_whitelist_post**](docs/OIDCApi.md#oidc_whitelistid_whitelist_post) | **POST** /oidc/whitelist/{id_whitelist} | Edit a authorized redirect uri
*PFMApi* | [**auth_confirm_new_email_post**](docs/PFMApi.md#auth_confirm_new_email_post) | **POST** /auth/confirmNewEmail | Confirm new email address
*PFMApi* | [**auth_confirm_post**](docs/PFMApi.md#auth_confirm_post) | **POST** /auth/confirm | Confirm email address
*PFMApi* | [**auth_cookie_post**](docs/PFMApi.md#auth_cookie_post) | **POST** /auth/cookie | Login with credentials and set as cookie
*PFMApi* | [**auth_register_post**](docs/PFMApi.md#auth_register_post) | **POST** /auth/register | Register to API
*PFMApi* | [**auth_resend_confirm_email_post**](docs/PFMApi.md#auth_resend_confirm_email_post) | **POST** /auth/resendConfirmEmail | Resend an email to confirm email address.
*PFMApi* | [**auth_token_delete**](docs/PFMApi.md#auth_token_delete) | **DELETE** /auth/token | Remove user access
*PFMApi* | [**auth_token_post**](docs/PFMApi.md#auth_token_post) | **POST** /auth/token | Login to API with credentials
*PFMApi* | [**hash_delete**](docs/PFMApi.md#hash_delete) | **DELETE** /hash | Delete the user&#39;s connections
*PFMApi* | [**usersid_user_accountsalert_get**](docs/PFMApi.md#usersid_user_accountsalert_get) | **GET** /users/{id_user}/accountsalert | Get alert configuration of a specific account
*PFMApi* | [**usersid_user_accountsalert_put**](docs/PFMApi.md#usersid_user_accountsalert_put) | **PUT** /users/{id_user}/accountsalert | Update alert configuration of an account
*PFMApi* | [**usersid_user_accountsid_account_balances_get**](docs/PFMApi.md#usersid_user_accountsid_account_balances_get) | **GET** /users/{id_user}/accounts/{id_account}/balances | Get balances of accounts
*PFMApi* | [**usersid_user_accountsid_account_operationsalert_get**](docs/PFMApi.md#usersid_user_accountsid_account_operationsalert_get) | **GET** /users/{id_user}/accounts/{id_account}/operationsalert | Get a list of configurated alerts
*PFMApi* | [**usersid_user_accountsid_account_operationsalert_post**](docs/PFMApi.md#usersid_user_accountsid_account_operationsalert_post) | **POST** /users/{id_user}/accounts/{id_account}/operationsalert | Create an alert on transactions or investemens of a given user
*PFMApi* | [**usersid_user_accountsid_account_operationsalertid_operationsalert_delete**](docs/PFMApi.md#usersid_user_accountsid_account_operationsalertid_operationsalert_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/operationsalert/{id_operationsalert} | Delete an alert on transactions or investemens
*PFMApi* | [**usersid_user_accountsid_account_operationsalertid_operationsalert_put**](docs/PFMApi.md#usersid_user_accountsid_account_operationsalertid_operationsalert_put) | **PUT** /users/{id_user}/accounts/{id_account}/operationsalert/{id_operationsalert} | Edit an alert on transactions or investemens
*PFMApi* | [**usersid_user_balances_get**](docs/PFMApi.md#usersid_user_balances_get) | **GET** /users/{id_user}/balances | Get balances of accounts
*PFMApi* | [**usersid_user_connectionsid_connection_accountsid_account_balances_get**](docs/PFMApi.md#usersid_user_connectionsid_connection_accountsid_account_balances_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/balances | Get balances of accounts
*PFMApi* | [**usersid_user_connectionsid_connection_accountsid_account_operationsalert_get**](docs/PFMApi.md#usersid_user_connectionsid_connection_accountsid_account_operationsalert_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/operationsalert | Get a list of configurated alerts
*PFMApi* | [**usersid_user_connectionsid_connection_accountsid_account_operationsalert_post**](docs/PFMApi.md#usersid_user_connectionsid_connection_accountsid_account_operationsalert_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/operationsalert | Create an alert on transactions or investemens of a given user
*PFMApi* | [**usersid_user_connectionsid_connection_accountsid_account_operationsalertid_operationsalert_delete**](docs/PFMApi.md#usersid_user_connectionsid_connection_accountsid_account_operationsalertid_operationsalert_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/operationsalert/{id_operationsalert} | Delete an alert on transactions or investemens
*PFMApi* | [**usersid_user_connectionsid_connection_accountsid_account_operationsalertid_operationsalert_put**](docs/PFMApi.md#usersid_user_connectionsid_connection_accountsid_account_operationsalertid_operationsalert_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/operationsalert/{id_operationsalert} | Edit an alert on transactions or investemens
*PFMApi* | [**usersid_user_connectionsid_connection_balances_get**](docs/PFMApi.md#usersid_user_connectionsid_connection_balances_get) | **GET** /users/{id_user}/connections/{id_connection}/balances | Get balances of accounts
*PFMApi* | [**usersid_user_devices_get**](docs/PFMApi.md#usersid_user_devices_get) | **GET** /users/{id_user}/devices | Get devices
*PFMApi* | [**usersid_user_devices_post**](docs/PFMApi.md#usersid_user_devices_post) | **POST** /users/{id_user}/devices | Create a device linked to specified token.
*PFMApi* | [**usersid_user_devicesid_device_delete**](docs/PFMApi.md#usersid_user_devicesid_device_delete) | **DELETE** /users/{id_user}/devices/{id_device} | Delete device.
*PFMApi* | [**usersid_user_devicesid_device_get**](docs/PFMApi.md#usersid_user_devicesid_device_get) | **GET** /users/{id_user}/devices/{id_device} | Get a device
*PFMApi* | [**usersid_user_devicesid_device_put**](docs/PFMApi.md#usersid_user_devicesid_device_put) | **PUT** /users/{id_user}/devices/{id_device} | Update attributes of the device.
*PFMApi* | [**usersid_user_forecast_get**](docs/PFMApi.md#usersid_user_forecast_get) | **GET** /users/{id_user}/forecast | Get forecast
*PFMApi* | [**usersid_user_get**](docs/PFMApi.md#usersid_user_get) | **GET** /users/{id_user} | Get a user
*PFMApi* | [**usersid_user_operationsalert_get**](docs/PFMApi.md#usersid_user_operationsalert_get) | **GET** /users/{id_user}/operationsalert | Get a list of configurated alerts
*PFMApi* | [**usersid_user_operationsalert_post**](docs/PFMApi.md#usersid_user_operationsalert_post) | **POST** /users/{id_user}/operationsalert | Create an alert on transactions or investemens of a given user
*PFMApi* | [**usersid_user_operationsalertid_operationsalert_delete**](docs/PFMApi.md#usersid_user_operationsalertid_operationsalert_delete) | **DELETE** /users/{id_user}/operationsalert/{id_operationsalert} | Delete an alert on transactions or investemens
*PFMApi* | [**usersid_user_operationsalertid_operationsalert_put**](docs/PFMApi.md#usersid_user_operationsalertid_operationsalert_put) | **PUT** /users/{id_user}/operationsalert/{id_operationsalert} | Edit an alert on transactions or investemens
*PFMApi* | [**usersid_user_profiles_get**](docs/PFMApi.md#usersid_user_profiles_get) | **GET** /users/{id_user}/profiles | Get profiles
*PFMApi* | [**usersid_user_profiles_main_get**](docs/PFMApi.md#usersid_user_profiles_main_get) | **GET** /users/{id_user}/profiles/main | Get the main profile
*PFMApi* | [**usersid_user_profiles_me_get**](docs/PFMApi.md#usersid_user_profiles_me_get) | **GET** /users/{id_user}/profiles/me | Get my profile
*PFMApi* | [**usersid_user_profiles_me_put**](docs/PFMApi.md#usersid_user_profiles_me_put) | **PUT** /users/{id_user}/profiles/me | Change settings of the profile.
*PFMApi* | [**usersid_user_profilesid_profile_get**](docs/PFMApi.md#usersid_user_profilesid_profile_get) | **GET** /users/{id_user}/profiles/{id_profile} | Get a profile
*PFMApi* | [**usersid_user_resume_get**](docs/PFMApi.md#usersid_user_resume_get) | **GET** /users/{id_user}/resume | Get synthesis configuration of a specific user
*PFMApi* | [**usersid_user_resume_post**](docs/PFMApi.md#usersid_user_resume_post) | **POST** /users/{id_user}/resume | Update synthesis configuration
*ProvidersApi* | [**banks_get**](docs/ProvidersApi.md#banks_get) | **GET** /banks | Get list of connectors
*ProvidersApi* | [**banksid_connector_logos_get**](docs/ProvidersApi.md#banksid_connector_logos_get) | **GET** /banks/{id_connector}/logos | Get all links to the files associated with this connector.
*ProvidersApi* | [**banksid_connector_logos_main_get**](docs/ProvidersApi.md#banksid_connector_logos_main_get) | **GET** /banks/{id_connector}/logos/main | Get all links to the files associated with this connector.
*ProvidersApi* | [**banksid_connector_logos_thumbnail_get**](docs/ProvidersApi.md#banksid_connector_logos_thumbnail_get) | **GET** /banks/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*ProvidersApi* | [**banksid_connector_sources_get**](docs/ProvidersApi.md#banksid_connector_sources_get) | **GET** /banks/{id_connector}/sources | Get list of connector sources
*ProvidersApi* | [**connections_get**](docs/ProvidersApi.md#connections_get) | **GET** /connections | Get connections without a user
*ProvidersApi* | [**connectionsid_connection_logs_get**](docs/ProvidersApi.md#connectionsid_connection_logs_get) | **GET** /connections/{id_connection}/logs | Get connection logs
*ProvidersApi* | [**connectionsid_connection_sources_get**](docs/ProvidersApi.md#connectionsid_connection_sources_get) | **GET** /connections/{id_connection}/sources | Get connection sources
*ProvidersApi* | [**connectionsid_connection_sourcesid_source_delete**](docs/ProvidersApi.md#connectionsid_connection_sourcesid_source_delete) | **DELETE** /connections/{id_connection}/sources/{id_source} | Disable a connection source
*ProvidersApi* | [**connectionsid_connection_sourcesid_source_post**](docs/ProvidersApi.md#connectionsid_connection_sourcesid_source_post) | **POST** /connections/{id_connection}/sources/{id_source} | Enable connection source
*ProvidersApi* | [**connectionsid_connection_sourcesid_source_put**](docs/ProvidersApi.md#connectionsid_connection_sourcesid_source_put) | **PUT** /connections/{id_connection}/sources/{id_source} | Enable connection source
*ProvidersApi* | [**connectors_get**](docs/ProvidersApi.md#connectors_get) | **GET** /connectors | Get list of connectors
*ProvidersApi* | [**connectors_post**](docs/ProvidersApi.md#connectors_post) | **POST** /connectors | Request a new connector
*ProvidersApi* | [**connectorsid_connector_logos_get**](docs/ProvidersApi.md#connectorsid_connector_logos_get) | **GET** /connectors/{id_connector}/logos | Get all links to the files associated with this connector.
*ProvidersApi* | [**connectorsid_connector_logos_main_get**](docs/ProvidersApi.md#connectorsid_connector_logos_main_get) | **GET** /connectors/{id_connector}/logos/main | Get all links to the files associated with this connector.
*ProvidersApi* | [**connectorsid_connector_logos_post**](docs/ProvidersApi.md#connectorsid_connector_logos_post) | **POST** /connectors/{id_connector}/logos | Create a connector Logo
*ProvidersApi* | [**connectorsid_connector_logos_put**](docs/ProvidersApi.md#connectorsid_connector_logos_put) | **PUT** /connectors/{id_connector}/logos | Create or Update a connector Logo
*ProvidersApi* | [**connectorsid_connector_logos_thumbnail_get**](docs/ProvidersApi.md#connectorsid_connector_logos_thumbnail_get) | **GET** /connectors/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*ProvidersApi* | [**connectorsid_connector_logosid_logo_delete**](docs/ProvidersApi.md#connectorsid_connector_logosid_logo_delete) | **DELETE** /connectors/{id_connector}/logos/{id_logo} | Delete a single Logo object.
*ProvidersApi* | [**connectorsid_connector_logosid_logo_put**](docs/ProvidersApi.md#connectorsid_connector_logosid_logo_put) | **PUT** /connectors/{id_connector}/logos/{id_logo} | Create or Update a connector Logo.
*ProvidersApi* | [**connectorsid_connector_sources_get**](docs/ProvidersApi.md#connectorsid_connector_sources_get) | **GET** /connectors/{id_connector}/sources | Get list of connector sources
*ProvidersApi* | [**connectorsid_connector_sourcesid_source_put**](docs/ProvidersApi.md#connectorsid_connector_sourcesid_source_put) | **PUT** /connectors/{id_connector}/sources/{id_source} | Edit the provided connector source
*ProvidersApi* | [**documenttypes_get**](docs/ProvidersApi.md#documenttypes_get) | **GET** /documenttypes | Get document types
*ProvidersApi* | [**documenttypesid_documenttype_put**](docs/ProvidersApi.md#documenttypesid_documenttype_put) | **PUT** /documenttypes/{id_documenttype} | Edit a document type
*ProvidersApi* | [**logs_get**](docs/ProvidersApi.md#logs_get) | **GET** /logs | Get connection logs
*ProvidersApi* | [**ocr_post**](docs/ProvidersApi.md#ocr_post) | **POST** /ocr | Post an image with OCR
*ProvidersApi* | [**providers_get**](docs/ProvidersApi.md#providers_get) | **GET** /providers | Get list of connectors
*ProvidersApi* | [**providersid_connector_logos_get**](docs/ProvidersApi.md#providersid_connector_logos_get) | **GET** /providers/{id_connector}/logos | Get all links to the files associated with this connector.
*ProvidersApi* | [**providersid_connector_logos_main_get**](docs/ProvidersApi.md#providersid_connector_logos_main_get) | **GET** /providers/{id_connector}/logos/main | Get all links to the files associated with this connector.
*ProvidersApi* | [**providersid_connector_logos_thumbnail_get**](docs/ProvidersApi.md#providersid_connector_logos_thumbnail_get) | **GET** /providers/{id_connector}/logos/thumbnail | Get all links to the files associated with this connector.
*ProvidersApi* | [**providersid_connector_sources_get**](docs/ProvidersApi.md#providersid_connector_sources_get) | **GET** /providers/{id_connector}/sources | Get list of connector sources
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_get**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_post**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_put**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_delete**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Delete documents
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_get**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Get documents
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_post**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Add a new document
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documents_put**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_accountsid_account_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connections_delete**](docs/ProvidersApi.md#usersid_user_connections_delete) | **DELETE** /users/{id_user}/connections | Delete all connections
*ProvidersApi* | [**usersid_user_connections_get**](docs/ProvidersApi.md#usersid_user_connections_get) | **GET** /users/{id_user}/connections | Get connections
*ProvidersApi* | [**usersid_user_connections_post**](docs/ProvidersApi.md#usersid_user_connections_post) | **POST** /users/{id_user}/connections | Add a new connection.
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_accountsid_account_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_delete) | **DELETE** /users/{id_user}/connections/{id_connection} | Delete a connection.
*ProvidersApi* | [**usersid_user_connectionsid_connection_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_informations_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_informations_get) | **GET** /users/{id_user}/connections/{id_connection}/informations | Get connection additionnal informations
*ProvidersApi* | [**usersid_user_connectionsid_connection_logs_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_logs_get) | **GET** /users/{id_user}/connections/{id_connection}/logs | Get connection logs
*ProvidersApi* | [**usersid_user_connectionsid_connection_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_post) | **POST** /users/{id_user}/connections/{id_connection} | Update a connection.
*ProvidersApi* | [**usersid_user_connectionsid_connection_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_put) | **PUT** /users/{id_user}/connections/{id_connection} | Force synchronisation of a connection.
*ProvidersApi* | [**usersid_user_connectionsid_connection_sources_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_sources_get) | **GET** /users/{id_user}/connections/{id_connection}/sources | Get connection sources
*ProvidersApi* | [**usersid_user_connectionsid_connection_sourcesid_source_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_sourcesid_source_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Disable a connection source
*ProvidersApi* | [**usersid_user_connectionsid_connection_sourcesid_source_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_sourcesid_source_post) | **POST** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*ProvidersApi* | [**usersid_user_connectionsid_connection_sourcesid_source_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_sourcesid_source_put) | **PUT** /users/{id_user}/connections/{id_connection}/sources/{id_source} | Enable connection source
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptions_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptions_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions | Update many subscriptions at once
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription} | Delete a subscription.
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_logs_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_logs_get) | **GET** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription}/logs | Get subscriptions logs.
*ProvidersApi* | [**usersid_user_connectionsid_connection_subscriptionsid_subscription_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_subscriptionsid_subscription_put) | **PUT** /users/{id_user}/connections/{id_connection}/subscriptions/{id_subscription} | Update a subscription
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Delete documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_get**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Get documents
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_post**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Add a new document
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documents_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_connectionsid_connection_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/connections/{id_connection}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_documents_delete**](docs/ProvidersApi.md#usersid_user_documents_delete) | **DELETE** /users/{id_user}/documents | Delete documents
*ProvidersApi* | [**usersid_user_documents_get**](docs/ProvidersApi.md#usersid_user_documents_get) | **GET** /users/{id_user}/documents | Get documents
*ProvidersApi* | [**usersid_user_documents_post**](docs/ProvidersApi.md#usersid_user_documents_post) | **POST** /users/{id_user}/documents | Add a new document
*ProvidersApi* | [**usersid_user_documents_put**](docs/ProvidersApi.md#usersid_user_documents_put) | **PUT** /users/{id_user}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_documentsid_document_delete) | **DELETE** /users/{id_user}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_documentsid_document_put) | **PUT** /users/{id_user}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_logs_get**](docs/ProvidersApi.md#usersid_user_logs_get) | **GET** /users/{id_user}/logs | Get connection logs
*ProvidersApi* | [**usersid_user_ocr_post**](docs/ProvidersApi.md#usersid_user_ocr_post) | **POST** /users/{id_user}/ocr | Post an image with OCR
*ProvidersApi* | [**usersid_user_subscriptions_put**](docs/ProvidersApi.md#usersid_user_subscriptions_put) | **PUT** /users/{id_user}/subscriptions | Update many subscriptions at once
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_delete**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_delete) | **DELETE** /users/{id_user}/subscriptions/{id_subscription} | Delete a subscription.
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documents_delete**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documents_delete) | **DELETE** /users/{id_user}/subscriptions/{id_subscription}/documents | Delete documents
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documents_get**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documents_get) | **GET** /users/{id_user}/subscriptions/{id_subscription}/documents | Get documents
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documents_post**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documents_post) | **POST** /users/{id_user}/subscriptions/{id_subscription}/documents | Add a new document
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documents_put**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documents_put) | **PUT** /users/{id_user}/subscriptions/{id_subscription}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documentsid_document_delete) | **DELETE** /users/{id_user}/subscriptions/{id_subscription}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_documentsid_document_put) | **PUT** /users/{id_user}/subscriptions/{id_subscription}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_logs_get**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_logs_get) | **GET** /users/{id_user}/subscriptions/{id_subscription}/logs | Get subscriptions logs.
*ProvidersApi* | [**usersid_user_subscriptionsid_subscription_put**](docs/ProvidersApi.md#usersid_user_subscriptionsid_subscription_put) | **PUT** /users/{id_user}/subscriptions/{id_subscription} | Update a subscription
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_delete**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_delete) | **DELETE** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Delete documents
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_get**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_get) | **GET** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Get documents
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_post**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_post) | **POST** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Add a new document
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documents_put**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documents_put) | **PUT** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_delete) | **DELETE** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_transactionsclustersid_transactions_cluster_documentsid_document_put) | **PUT** /users/{id_user}/transactionsclusters/{id_transactions_cluster}/documents/{id_document} | Edit a document
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documents_delete**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documents_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/documents | Delete documents
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documents_get**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documents_get) | **GET** /users/{id_user}/transactions/{id_transaction}/documents | Get documents
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documents_post**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documents_post) | **POST** /users/{id_user}/transactions/{id_transaction}/documents | Add a new document
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documents_put**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documents_put) | **PUT** /users/{id_user}/transactions/{id_transaction}/documents | Attach an existing document to a transaction or a transactions_cluster
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documentsid_document_delete**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documentsid_document_delete) | **DELETE** /users/{id_user}/transactions/{id_transaction}/documents/{id_document} | Delete a document
*ProvidersApi* | [**usersid_user_transactionsid_transaction_documentsid_document_put**](docs/ProvidersApi.md#usersid_user_transactionsid_transaction_documentsid_document_put) | **PUT** /users/{id_user}/transactions/{id_transaction}/documents/{id_document} | Edit a document
*RecipientsApi* | [**usersid_user_accountsid_account_recipients_post**](docs/RecipientsApi.md#usersid_user_accountsid_account_recipients_post) | **POST** /users/{id_user}/accounts/{id_account}/recipients | Add a recipient.
*RecipientsApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipients_post**](docs/RecipientsApi.md#usersid_user_connectionsid_connection_accountsid_account_recipients_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients | Add a recipient.
*RecipientsApi* | [**usersid_user_connectionsid_connection_recipients_post**](docs/RecipientsApi.md#usersid_user_connectionsid_connection_recipients_post) | **POST** /users/{id_user}/connections/{id_connection}/recipients | Add a recipient.
*RecipientsApi* | [**usersid_user_recipients_post**](docs/RecipientsApi.md#usersid_user_recipients_post) | **POST** /users/{id_user}/recipients | Add a recipient.
*TermsApi* | [**terms_get**](docs/TermsApi.md#terms_get) | **GET** /terms | Return the current terms and the content of the associated file
*TermsApi* | [**terms_post**](docs/TermsApi.md#terms_post) | **POST** /terms | Register a version of &#39;Terms of Service&#39; in database
*TermsApi* | [**termsid_term_post**](docs/TermsApi.md#termsid_term_post) | **POST** /terms/{id_term} | Add terms content for a language. Only for the active terms, there is no use to update obsolete terms
*TermsApi* | [**usersid_user_terms_get**](docs/TermsApi.md#usersid_user_terms_get) | **GET** /users/{id_user}/terms | Get active terms object for a specific user, only one terms can be active
*TermsApi* | [**usersid_user_terms_post**](docs/TermsApi.md#usersid_user_terms_post) | **POST** /users/{id_user}/terms | Register user&#39;s consent for a specific terms id
*TransferApi* | [**webauth_get**](docs/TransferApi.md#webauth_get) | **GET** /webauth | First step to establish an oAuth2 connection.
*TransfersApi* | [**usersid_user_accountsid_account_recipients_get**](docs/TransfersApi.md#usersid_user_accountsid_account_recipients_get) | **GET** /users/{id_user}/accounts/{id_account}/recipients | Returns the list of recipients.
*TransfersApi* | [**usersid_user_accountsid_account_recipientsid_recipient_post**](docs/TransfersApi.md#usersid_user_accountsid_account_recipientsid_recipient_post) | **POST** /users/{id_user}/accounts/{id_account}/recipients/{id_recipient} | Continue addition of a recipient.
*TransfersApi* | [**usersid_user_accountsid_account_recipientsid_recipient_transfers_get**](docs/TransfersApi.md#usersid_user_accountsid_account_recipientsid_recipient_transfers_get) | **GET** /users/{id_user}/accounts/{id_account}/recipients/{id_recipient}/transfers | Get transfers
*TransfersApi* | [**usersid_user_accountsid_account_recipientsid_recipient_transfers_post**](docs/TransfersApi.md#usersid_user_accountsid_account_recipientsid_recipient_transfers_post) | **POST** /users/{id_user}/accounts/{id_account}/recipients/{id_recipient}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_accountsid_account_recipientsid_recipient_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_accountsid_account_recipientsid_recipient_transfersid_transfer_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/recipients/{id_recipient}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_accountsid_account_recipientsid_recipient_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_accountsid_account_recipientsid_recipient_transfersid_transfer_post) | **POST** /users/{id_user}/accounts/{id_account}/recipients/{id_recipient}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_accountsid_account_transfers_get**](docs/TransfersApi.md#usersid_user_accountsid_account_transfers_get) | **GET** /users/{id_user}/accounts/{id_account}/transfers | Get transfers
*TransfersApi* | [**usersid_user_accountsid_account_transfers_post**](docs/TransfersApi.md#usersid_user_accountsid_account_transfers_post) | **POST** /users/{id_user}/accounts/{id_account}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_accountsid_account_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_accountsid_account_transfersid_transfer_delete) | **DELETE** /users/{id_user}/accounts/{id_account}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_accountsid_account_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_accountsid_account_transfersid_transfer_post) | **POST** /users/{id_user}/accounts/{id_account}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipients_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipients_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients | Returns the list of recipients.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients/{id_recipient} | Continue addition of a recipient.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfers_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfers_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients/{id_recipient}/transfers | Get transfers
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfers_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfers_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients/{id_recipient}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfersid_transfer_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients/{id_recipient}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_recipientsid_recipient_transfersid_transfer_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/recipients/{id_recipient}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transfers_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_transfers_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transfers | Get transfers
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transfers_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_transfers_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_transfersid_transfer_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_accountsid_account_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_accountsid_account_transfersid_transfer_post) | **POST** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_recipients_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipients_get) | **GET** /users/{id_user}/connections/{id_connection}/recipients | Returns the list of recipients.
*TransfersApi* | [**usersid_user_connectionsid_connection_recipientsid_recipient_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipientsid_recipient_post) | **POST** /users/{id_user}/connections/{id_connection}/recipients/{id_recipient} | Continue addition of a recipient.
*TransfersApi* | [**usersid_user_connectionsid_connection_recipientsid_recipient_transfers_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipientsid_recipient_transfers_get) | **GET** /users/{id_user}/connections/{id_connection}/recipients/{id_recipient}/transfers | Get transfers
*TransfersApi* | [**usersid_user_connectionsid_connection_recipientsid_recipient_transfers_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipientsid_recipient_transfers_post) | **POST** /users/{id_user}/connections/{id_connection}/recipients/{id_recipient}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_connectionsid_connection_recipientsid_recipient_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipientsid_recipient_transfersid_transfer_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/recipients/{id_recipient}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_recipientsid_recipient_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_recipientsid_recipient_transfersid_transfer_post) | **POST** /users/{id_user}/connections/{id_connection}/recipients/{id_recipient}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_transfers_get**](docs/TransfersApi.md#usersid_user_connectionsid_connection_transfers_get) | **GET** /users/{id_user}/connections/{id_connection}/transfers | Get transfers
*TransfersApi* | [**usersid_user_connectionsid_connection_transfers_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_transfers_post) | **POST** /users/{id_user}/connections/{id_connection}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_connectionsid_connection_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_connectionsid_connection_transfersid_transfer_delete) | **DELETE** /users/{id_user}/connections/{id_connection}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_connectionsid_connection_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_connectionsid_connection_transfersid_transfer_post) | **POST** /users/{id_user}/connections/{id_connection}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_recipients_get**](docs/TransfersApi.md#usersid_user_recipients_get) | **GET** /users/{id_user}/recipients | Returns the list of recipients.
*TransfersApi* | [**usersid_user_recipientsid_recipient_post**](docs/TransfersApi.md#usersid_user_recipientsid_recipient_post) | **POST** /users/{id_user}/recipients/{id_recipient} | Continue addition of a recipient.
*TransfersApi* | [**usersid_user_recipientsid_recipient_transfers_get**](docs/TransfersApi.md#usersid_user_recipientsid_recipient_transfers_get) | **GET** /users/{id_user}/recipients/{id_recipient}/transfers | Get transfers
*TransfersApi* | [**usersid_user_recipientsid_recipient_transfers_post**](docs/TransfersApi.md#usersid_user_recipientsid_recipient_transfers_post) | **POST** /users/{id_user}/recipients/{id_recipient}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_recipientsid_recipient_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_recipientsid_recipient_transfersid_transfer_delete) | **DELETE** /users/{id_user}/recipients/{id_recipient}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_recipientsid_recipient_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_recipientsid_recipient_transfersid_transfer_post) | **POST** /users/{id_user}/recipients/{id_recipient}/transfers/{id_transfer} | Execute or edit a Transfer.
*TransfersApi* | [**usersid_user_transfers_get**](docs/TransfersApi.md#usersid_user_transfers_get) | **GET** /users/{id_user}/transfers | Get transfers
*TransfersApi* | [**usersid_user_transfers_post**](docs/TransfersApi.md#usersid_user_transfers_post) | **POST** /users/{id_user}/transfers | Create a transfer object.
*TransfersApi* | [**usersid_user_transfersid_transfer_delete**](docs/TransfersApi.md#usersid_user_transfersid_transfer_delete) | **DELETE** /users/{id_user}/transfers/{id_transfer} | Cancel a transfer.
*TransfersApi* | [**usersid_user_transfersid_transfer_post**](docs/TransfersApi.md#usersid_user_transfersid_transfer_post) | **POST** /users/{id_user}/transfers/{id_transfer} | Execute or edit a Transfer.
*UsersManagementApi* | [**hash_delete**](docs/UsersManagementApi.md#hash_delete) | **DELETE** /hash | Delete the user&#39;s connections
*UsersManagementApi* | [**users_get**](docs/UsersManagementApi.md#users_get) | **GET** /users | Get users
*UsersManagementApi* | [**usersid_user_config_delete**](docs/UsersManagementApi.md#usersid_user_config_delete) | **DELETE** /users/{id_user}/config | Delete the given user configurations. deletions on keys prefixed by &#39;biapi.&#39; (except callback_url) are ignored
*UsersManagementApi* | [**usersid_user_config_get**](docs/UsersManagementApi.md#usersid_user_config_get) | **GET** /users/{id_user}/config | Get configuration of a user.
*UsersManagementApi* | [**usersid_user_config_post**](docs/UsersManagementApi.md#usersid_user_config_post) | **POST** /users/{id_user}/config | Change configuration of a user. modifications on keys prefixed by &#39;biapi.&#39; (except callback_url) are ignored
*UsersManagementApi* | [**usersid_user_delete**](docs/UsersManagementApi.md#usersid_user_delete) | **DELETE** /users/{id_user} | Delete the user
*UsersManagementApi* | [**usersid_user_get**](docs/UsersManagementApi.md#usersid_user_get) | **GET** /users/{id_user} | Get a user
*UsersManagementApi* | [**usersid_user_profiles_get**](docs/UsersManagementApi.md#usersid_user_profiles_get) | **GET** /users/{id_user}/profiles | Get profiles
*UsersManagementApi* | [**usersid_user_profiles_main_get**](docs/UsersManagementApi.md#usersid_user_profiles_main_get) | **GET** /users/{id_user}/profiles/main | Get the main profile
*UsersManagementApi* | [**usersid_user_profiles_me_get**](docs/UsersManagementApi.md#usersid_user_profiles_me_get) | **GET** /users/{id_user}/profiles/me | Get my profile
*UsersManagementApi* | [**usersid_user_profilesid_profile_get**](docs/UsersManagementApi.md#usersid_user_profilesid_profile_get) | **GET** /users/{id_user}/profiles/{id_profile} | Get a profile
*UsersManagementApi* | [**usersid_user_token_post**](docs/UsersManagementApi.md#usersid_user_token_post) | **POST** /users/{id_user}/token | Create a token
*WealthApi* | [**finance_securities_get**](docs/WealthApi.md#finance_securities_get) | **GET** /finance/securities | Get securities
*WealthApi* | [**finance_securitiesid_security_history_get**](docs/WealthApi.md#finance_securitiesid_security_history_get) | **GET** /finance/securities/{id_security}/history | Get connection logs
*WealthApi* | [**usersid_user_accountsid_account_investments_get**](docs/WealthApi.md#usersid_user_accountsid_account_investments_get) | **GET** /users/{id_user}/accounts/{id_account}/investments | Get investments
*WealthApi* | [**usersid_user_accountsid_account_investmentsid_investment_history_get**](docs/WealthApi.md#usersid_user_accountsid_account_investmentsid_investment_history_get) | **GET** /users/{id_user}/accounts/{id_account}/investments/{id_investment}/history | Get investment values
*WealthApi* | [**usersid_user_accountsid_account_investmentsid_investment_pockets_get**](docs/WealthApi.md#usersid_user_accountsid_account_investmentsid_investment_pockets_get) | **GET** /users/{id_user}/accounts/{id_account}/investments/{id_investment}/pockets | Get pockets
*WealthApi* | [**usersid_user_accountsid_account_investmentsid_investment_security_history_get**](docs/WealthApi.md#usersid_user_accountsid_account_investmentsid_investment_security_history_get) | **GET** /users/{id_user}/accounts/{id_account}/investments/{id_investment}/security/history | Get connection logs
*WealthApi* | [**usersid_user_accountsid_account_pockets_get**](docs/WealthApi.md#usersid_user_accountsid_account_pockets_get) | **GET** /users/{id_user}/accounts/{id_account}/pockets | Get pockets
*WealthApi* | [**usersid_user_connectionsid_connection_accountsid_account_investments_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_accountsid_account_investments_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/investments | Get investments
*WealthApi* | [**usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_history_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_history_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/investments/{id_investment}/history | Get investment values
*WealthApi* | [**usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_pockets_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_pockets_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/investments/{id_investment}/pockets | Get pockets
*WealthApi* | [**usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_security_history_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_accountsid_account_investmentsid_investment_security_history_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/investments/{id_investment}/security/history | Get connection logs
*WealthApi* | [**usersid_user_connectionsid_connection_accountsid_account_pockets_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_accountsid_account_pockets_get) | **GET** /users/{id_user}/connections/{id_connection}/accounts/{id_account}/pockets | Get pockets
*WealthApi* | [**usersid_user_connectionsid_connection_investments_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_investments_get) | **GET** /users/{id_user}/connections/{id_connection}/investments | Get investments
*WealthApi* | [**usersid_user_connectionsid_connection_investmentsid_investment_history_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_investmentsid_investment_history_get) | **GET** /users/{id_user}/connections/{id_connection}/investments/{id_investment}/history | Get investment values
*WealthApi* | [**usersid_user_connectionsid_connection_investmentsid_investment_pockets_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_investmentsid_investment_pockets_get) | **GET** /users/{id_user}/connections/{id_connection}/investments/{id_investment}/pockets | Get pockets
*WealthApi* | [**usersid_user_connectionsid_connection_investmentsid_investment_security_history_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_investmentsid_investment_security_history_get) | **GET** /users/{id_user}/connections/{id_connection}/investments/{id_investment}/security/history | Get connection logs
*WealthApi* | [**usersid_user_connectionsid_connection_pockets_get**](docs/WealthApi.md#usersid_user_connectionsid_connection_pockets_get) | **GET** /users/{id_user}/connections/{id_connection}/pockets | Get pockets
*WealthApi* | [**usersid_user_investments_get**](docs/WealthApi.md#usersid_user_investments_get) | **GET** /users/{id_user}/investments | Get investments
*WealthApi* | [**usersid_user_investmentsid_investment_history_get**](docs/WealthApi.md#usersid_user_investmentsid_investment_history_get) | **GET** /users/{id_user}/investments/{id_investment}/history | Get investment values
*WealthApi* | [**usersid_user_investmentsid_investment_pockets_get**](docs/WealthApi.md#usersid_user_investmentsid_investment_pockets_get) | **GET** /users/{id_user}/investments/{id_investment}/pockets | Get pockets
*WealthApi* | [**usersid_user_investmentsid_investment_security_history_get**](docs/WealthApi.md#usersid_user_investmentsid_investment_security_history_get) | **GET** /users/{id_user}/investments/{id_investment}/security/history | Get connection logs
*WealthApi* | [**usersid_user_pockets_get**](docs/WealthApi.md#usersid_user_pockets_get) | **GET** /users/{id_user}/pockets | Get pockets
*DefaultApi* | [**categorize_put**](docs/DefaultApi.md#categorize_put) | **PUT** /categorize | 


## Documentation For Models

 - [Access](docs/Access.md)
 - [Account](docs/Account.md)
 - [AccountLog](docs/AccountLog.md)
 - [AccountType](docs/AccountType.md)
 - [AccountTypes](docs/AccountTypes.md)
 - [AccountsAlert](docs/AccountsAlert.md)
 - [Alert](docs/Alert.md)
 - [AuthConfirm](docs/AuthConfirm.md)
 - [AuthInit](docs/AuthInit.md)
 - [AuthJwt](docs/AuthJwt.md)
 - [AuthJwtPayload](docs/AuthJwtPayload.md)
 - [AuthJwtPayloadPayload](docs/AuthJwtPayloadPayload.md)
 - [AuthProvider](docs/AuthProvider.md)
 - [AuthRegister](docs/AuthRegister.md)
 - [AuthToken](docs/AuthToken.md)
 - [AuthTokenAccess](docs/AuthTokenAccess.md)
 - [AuthTokenCode](docs/AuthTokenCode.md)
 - [Banks](docs/Banks.md)
 - [Categories](docs/Categories.md)
 - [CategorizeData](docs/CategorizeData.md)
 - [CategorizeTransaction](docs/CategorizeTransaction.md)
 - [Category](docs/Category.md)
 - [Certificate](docs/Certificate.md)
 - [Client](docs/Client.md)
 - [Clients](docs/Clients.md)
 - [Config](docs/Config.md)
 - [ConfigLog](docs/ConfigLog.md)
 - [ConfigLogs](docs/ConfigLogs.md)
 - [Connection](docs/Connection.md)
 - [ConnectionAccount](docs/ConnectionAccount.md)
 - [ConnectionAccountLoan](docs/ConnectionAccountLoan.md)
 - [ConnectionBank](docs/ConnectionBank.md)
 - [ConnectionInformations](docs/ConnectionInformations.md)
 - [ConnectionLog](docs/ConnectionLog.md)
 - [ConnectionSource](docs/ConnectionSource.md)
 - [ConnectionSources](docs/ConnectionSources.md)
 - [ConnectionSubscription](docs/ConnectionSubscription.md)
 - [Connections](docs/Connections.md)
 - [Connector](docs/Connector.md)
 - [ConnectorCategory](docs/ConnectorCategory.md)
 - [ConnectorLogo](docs/ConnectorLogo.md)
 - [ConnectorSource](docs/ConnectorSource.md)
 - [Connectors](docs/Connectors.md)
 - [Currency](docs/Currency.md)
 - [Device](docs/Device.md)
 - [Document](docs/Document.md)
 - [DocumentType](docs/DocumentType.md)
 - [Documenttypes](docs/Documenttypes.md)
 - [Field](docs/Field.md)
 - [File](docs/File.md)
 - [FinanceSecurities](docs/FinanceSecurities.md)
 - [Group](docs/Group.md)
 - [HashTable](docs/HashTable.md)
 - [Investment](docs/Investment.md)
 - [InvestmentValue](docs/InvestmentValue.md)
 - [Keyword](docs/Keyword.md)
 - [LockedUser](docs/LockedUser.md)
 - [Logs](docs/Logs.md)
 - [OidcWhitelist](docs/OidcWhitelist.md)
 - [Order](docs/Order.md)
 - [Pocket](docs/Pocket.md)
 - [Profile](docs/Profile.md)
 - [Project](docs/Project.md)
 - [ProjectType](docs/ProjectType.md)
 - [ProviderLogos](docs/ProviderLogos.md)
 - [ProviderSources](docs/ProviderSources.md)
 - [Providers](docs/Providers.md)
 - [Push](docs/Push.md)
 - [Recipient](docs/Recipient.md)
 - [RecipientLog](docs/RecipientLog.md)
 - [Security](docs/Security.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionLog](docs/SubscriptionLog.md)
 - [Terms](docs/Terms.md)
 - [TermsOfService](docs/TermsOfService.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionInformation](docs/TransactionInformation.md)
 - [TransactionsCluster](docs/TransactionsCluster.md)
 - [Transfer](docs/Transfer.md)
 - [TransferLog](docs/TransferLog.md)
 - [User](docs/User.md)
 - [UserAccountHistory](docs/UserAccountHistory.md)
 - [UserAccountLogs](docs/UserAccountLogs.md)
 - [UserAccounts](docs/UserAccounts.md)
 - [UserAlert](docs/UserAlert.md)
 - [UserAlerts](docs/UserAlerts.md)
 - [UserBalance](docs/UserBalance.md)
 - [UserBalanceCurrency](docs/UserBalanceCurrency.md)
 - [UserBalances](docs/UserBalances.md)
 - [UserCategoriesFull](docs/UserCategoriesFull.md)
 - [UserConfigKeys](docs/UserConfigKeys.md)
 - [UserConnectionInformations](docs/UserConnectionInformations.md)
 - [UserDevices](docs/UserDevices.md)
 - [UserDocuments](docs/UserDocuments.md)
 - [UserInvestments](docs/UserInvestments.md)
 - [UserOperationsalert](docs/UserOperationsalert.md)
 - [UserPockets](docs/UserPockets.md)
 - [UserProfiles](docs/UserProfiles.md)
 - [UserRecipients](docs/UserRecipients.md)
 - [UserResume](docs/UserResume.md)
 - [UserSubscriptionLogs](docs/UserSubscriptionLogs.md)
 - [UserToken](docs/UserToken.md)
 - [UserTransactionInformations](docs/UserTransactionInformations.md)
 - [UserTransactions](docs/UserTransactions.md)
 - [UserTransactionsclusters](docs/UserTransactionsclusters.md)
 - [UserTransfers](docs/UserTransfers.md)
 - [Users](docs/Users.md)
 - [WebHookLogs](docs/WebHookLogs.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookData](docs/WebhookData.md)
 - [WebhookLog](docs/WebhookLog.md)
 - [Webhooks](docs/Webhooks.md)
 - [WebhooksAuth](docs/WebhooksAuth.md)


## Documentation For Authorization


## Authorization

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

rienafairefr@gmail.com


